import React, { useMemo, useState, useEffect } from 'react'

import TPMMDEditor from '../../../modules/tpm/challengesnew/tpm-md-editor'
import './index.scss'
import RenderHtml from '../../../components/render-html'

function noop() { }

export const defaultQuillOpt = [
  'bold', 'italic', 'underline',
  { list: 'ordered' }, { list: 'bullet' },
  { script: 'sub' }, { script: 'super' },
  { 'color': [] },
  { 'background': [] },
  'image', 'code-block', 'formula', 'clean'
]
export default ({ is_md, value, onChange, placeholder, autoFocus = true, isError, isShowEditor, height = 160, options = defaultQuillOpt, index, onActiveOption = noop, md_id, showResizeBar = false }) => {

  const [isFocus, setIsFocus] = useState(false)
  useEffect(() => {
    if (isShowEditor) {
      setIsFocus(autoFocus)
    } else {
      setIsFocus(false)
    }
  }, [autoFocus, isShowEditor])


  function onMdContentChangeHandler(v) {
    onChange(v, index)
  }

  function onActiveHandler(e) {
    e.preventDefault()
    e.stopPropagation()
    onActiveOption(index)
  }
  return (
    <div className='editor-content-panel-wrapper'>
      <div className={`editor-content-panel  ${isShowEditor ? 'hide' : null} ${isError ? 'error' : null} ${value ? 'hasValue' : null} `}
        onClick={onActiveHandler} >
        <RenderHtml value={value || placeholder} />
      </div>

      {is_md ?
        <TPMMDEditor
          initValue={value}
          height={height}
          mdID={md_id}
          noStorage={true}
          className={`${isShowEditor ? null : 'hideMd'} ${isError ? 'md-error' : null} `}
          onChange={onMdContentChangeHandler}
          showResizeBar={showResizeBar}
          placeholder={placeholder}
        /> : null
      }

    </div>
  )
}