import React, { Component } from 'react';
import axios from 'axios'
import moment from 'moment'
import Comments from '../../comment/Comments'
import { ImageLayerOfCommentHOC } from '../../page/layers/ImageLayerOfCommentHOC'
import MemoDetailMDEditor from '../../forums/memo-detail-md-editor'
import { RouteHOC } from './common.js'
import '../../forums/Post.css'
import '../../forums/RightSection.css'
import './TopicDetail.css'
import '../common/courseMessage.css'
import { Pagination, Tooltip, Button } from 'antd'
import { setImagesUrl } from 'educoder'
import SendToCourseModal from '../coursesPublic/modal/SendToCourseModal'
import CBreadcrumb from '../common/CBreadcrumb'
import {
  generateComments, generateChildComments, _findById, handleContentBeforeCreateNew, addNewComment
  , addSecondLevelComment, handleContentBeforeCreateSecondLevelComment
  , handleDeleteComment, handleCommentPraise, handleHiddenComment
} from '../common/CommentsHelper'
import RenderHtml from '../../../components/render-html';

const $ = window.$
const REPLY_PAGE_COUNT = 10;
let setTime;
class TopicDetail extends Component {
  constructor(props) {
    super(props)

    this.state = {
      memo: {},
      memoLoading: true,
      hasMoreComments: false,
      pageCount: 1,
      comments: [],
      goldRewardDialogOpen: false,
      author: undefined,
      commentstype: false,
      active: false
    }
  }
  componentDidMount() {
    window.$("html,body").animate({ "scrollTop": 0 })

    const topicId = this.props.match.params.topicId

    const memoUrl = `/messages/${topicId}.json`;
    this.setState({
      memoLoading: true
    })
    axios.get(memoUrl, {
    })
      .then((response) => {

        if (response.data.status === -1) {
          setTimeout(() => {
            this.props.showNotification('帖子不存在！')
          }, 300)
          return;
        } else {

          this.setState({
            memo: Object.assign({}, {
              ...response.data.data,
              replies_count: response.data.data.total_replies_count
            }, { ...this.state.memo }),
            author: response.data.data.author
          })
        }
        this.setState({
          memoLoading: false
        })

      }).catch((error) => {
        console.log(error)
      })

    this.fetchReplies()

    $('body>#root').on('onMemoDelete', (event) => {
      const val = window.onMemoDelete;
      this.onMemoDelete(JSON.parse(decodeURIComponent(val)))
    })
  }

  onPaginationChange = (pageCount) => {
    this.setState({ pageCount }, () => {
      this.fetchReplies()
    })
  }

  componentWillUnmount() {
    $('body>#root').off('onMemoDelete')
  }
  onMemoDelete(memo) {
    const deleteUrl = `/commons/delete.json`;
    // 获取memo list
    axios.delete(deleteUrl, {
      data: {
        object_id: memo.id,
        object_type: 'message'
      }
    })
      .then((response) => {
        const status = response.data.status
        if (status === 0) {

          this.props.showNotification('删除成功');
          const props = Object.assign({}, this.props, {})
          this.props.toListPage(Object.assign({}, this.props.match.params, { 'coursesId': this.state.memo.course_id }))

        } else if (status === -1) {
          this.props.showNotification('帖子已被删除');
          this.props.history.push(`/forums`)
        }
      }).catch((error) => {
        console.log(error)
      })
  }

  clickPraise() {
    const { memo } = this.state;
    const url = memo.user_praise ? '/praise_tread/unlike.json' : `/praise_tread/like.json`;
    const _method = memo.user_praise ? axios.delete : axios.post
    let _data = {
      object_id: memo.id,
      object_type: 'message',  //Discuss
    }
    if (memo.user_praise) {
      _data = {
        data: _data
      }
    }
    _method(url, {
      ..._data
    }).then((response) => {

      const newMemo = Object.assign({}, this.state.memo)
      newMemo.praises_count = newMemo.user_praise ? newMemo.praises_count - 1 : newMemo.praises_count + 1
      newMemo.total_praises_count = newMemo.user_praise ? newMemo.total_praises_count - 1 : newMemo.total_praises_count + 1
      newMemo.user_praise = !newMemo.user_praise
      this.setState({ memo: newMemo })
    }).catch((error) => {
      console.log(error)
    })
  }
  renderAttachment() {
    const { memo } = this.state;
    const attachments = []
    memo.attachments.forEach((item, index) => {
      const ar = item.url.split('/')
      const fileName = item.title || ar[ar.length - 1]
      attachments.push(
        <div className="color-grey df" key={index}>
          <a className="color-grey ">
            <i className="font-14 color-green iconfont icon-fujian mr8" aria-hidden="true"></i>
          </a>
          <a href={item.url} title={fileName.length > 30 ? fileName : ''}
            className="mr12 color9B9B overflowHidden1" length="58" style={{ maxWidth: '480px' }}>
            {fileName}
          </a>
          <span className="color656565 mt2 color-grey-6 font-12 mr8">{item.filesize}</span>
        </div>
      )
    })
    return attachments;
  }
  transformReply = (reply, children = []) => {
    const isAdmin = this.props.isAdmin()
    const isSuperAdmin = this.props.isSuperAdmin()
    return {
      isSuperAdmin: isSuperAdmin,
      admin: isAdmin, //
      permission: true, //
      children: children,
      child_message_count: reply.total_count,
      hidden: reply.is_hidden,
      id: reply.id,
      image_url: reply.author.image_url,
      reward: null, //
      time: moment(reply.created_on).fromNow(),
      user_id: reply.author.id,
      user_login: reply.author.login,
      user_praise: reply.liked,
      username: reply.author.name,
      content: reply.content,
      praise_count: reply.praises_count
    }
  }

  fetchReplies = () => {
    const topicId = this.props.match.params.topicId
    const url = `/messages/${topicId}/reply_list.json?page=${this.state.pageCount}&page_size=${REPLY_PAGE_COUNT}`
    axios.get(url)
      .then((response) => {
        const { replies, liked, total_replies_count, total_count } = response.data.data

        const memo = Object.assign({}, this.state.memo)
        memo.user_praise = liked
        memo.total_replies_count = total_replies_count;
        this.setState({
          memo,
          comments: generateComments(replies, this.transformReply, 'replies'),
          total_count: total_count
        })
      }).catch((error) => {
        console.log(error)
      })
  }

  _getUser() {
    const { current_user } = this.props;
    current_user.user_url = `/users/${current_user.login}`;
    return current_user;
  }
  _findById = _findById
  replyComment = (commentContent, id) => {
    if (this.state.memo.id === id) { // 回复帖子
      this.createNewComment(commentContent, id);
      this.setState({
        active: false
      })
      return;
    }
    const url = `/messages/${id}/reply.json`;

    const { comments } = this.state;
    const user = this._getUser();
    commentContent = handleContentBeforeCreateSecondLevelComment(commentContent)
    if (!commentContent) {
      this.props.showNotification('不能为空')
      return;
    }
    axios.post(url, {
      content: commentContent
    }).then((response) => {
      if (response.data.data.id) {
        let newId = response.data.data.id;
        const commentIndex = this._findById(id, comments);
        const parentComment = comments[commentIndex]

        const newMemo2 = Object.assign({}, this.state.memo);
        newMemo2.total_replies_count = newMemo2.total_replies_count + 1;

        this.setState({
          comments: addSecondLevelComment(comments, parentComment, commentIndex, newId, commentContent, user),
          memo: newMemo2
        })
      }

    }).catch((error) => {
      console.log(error)
    })
  }
  // 公共接口 --- 删除回复
  deleteComment = (parrentComment, childCommentId) => {
    handleDeleteComment(this, parrentComment, childCommentId, 'message')

  }
  // 公共接口 --- 回复点赞
  commentPraise = (discussId) => {
    handleCommentPraise(this, discussId, 'message', (old_user_praise) => {
      const newMemo2 = Object.assign({}, this.state.memo);

      newMemo2.total_praises_count = old_user_praise
        ? newMemo2.total_praises_count - 1 : newMemo2.total_praises_count + 1;
      this.setState({
        memo: newMemo2
      })
    })
  }
  // 公共接口 --- 隐藏回复
  hiddenComment = (item, childCommentId) => {
    handleHiddenComment(this, item, childCommentId, 'message')
  }
  createNewComment = (commentContent, id) => {
    let content = handleContentBeforeCreateNew(commentContent);
    const url = `/messages/${id}/reply.json`;
    let { comments } = this.state;
    axios.post(url, { content: content }).then((response) => {
      if (response.data.status === -1) {
        console.error('服务端异常')
        return;
      }

      if (response.data) {
        const _id = response.data.data.id;

        const user = this._getUser();
        this.setState({
          comments: addNewComment(comments, _id, content, user, this.props.isSuperAdmin(), this)
        })
        const newMemo2 = Object.assign({}, this.state.memo);
        newMemo2.total_replies_count = newMemo2.total_replies_count + 1;
        this.setState({
          memo: newMemo2
        })


      }
    }).catch((error) => {
      console.log(error)
    })
  }

  /**
   * parent.isAllChildrenLoaded 为 true的时候，表示已经没有更多子回复了
   */
  loadMoreChildComments = (parent) => {
    const url = `/messages/${parent.id}/reply_list.json?page=1&page_size=500`
    axios.get(url, {
    })
      .then((response) => {
        const { replies, } = response.data.data

        this.setState({
          comments: generateChildComments(replies, this.state.comments, parent, this.transformReply)
        })
      }).catch((error) => {
        console.log(error)
      })
  }
  // 置顶
  setTop(memo) {
    const set_top_or_down_Url = `/messages/${memo.id}/sticky_top.json`;
    axios.put(set_top_or_down_Url)
      .then((response) => {
        const status = response.data.status
        if (status === 0) {
          this.props.showNotification(memo.sticky ? '取消置顶成功' : '置顶成功');
          memo.sticky = memo.sticky ? false : true
          this.setState({
            memo: Object.assign({}, memo)
          })
        }
      }).catch((error) => {
        console.log(error)
      })
  }

  setRewardDialogVisible = (visible) => {
    this.setState({
      goldRewardDialogOpen: visible
    })
  }
  showRewardDialog = () => {
    this.setState({
      goldRewardDialogOpen: true
    })
  }
  showCommentInput = () => {
    this.setState({
      active: true
    })
  }
  initReply = (parent) => {
    if (!parent.isAllChildrenLoaded) {
      this.loadMoreChildComments(parent)
    }
  }

  startcomments = () => {
    setTime = setInterval(() => {
      this.fetchReplies()
    }, 5000);
    this.setState({
      commentstype: true
    })
  }

  clearcomments = () => {
    clearInterval(setTime);
    this.setState({
      commentstype: false
    })
  }

  render() {
    const { match, history } = this.props
    const { recommend_shixun, current_user, author_info } = this.props;
    const { memo, comments, hasMoreComments, commentstype, pageCount, total_count, author } = this.state;
    const messageId = match.params.topicId
    if (this.state.memoLoading || !current_user) {
      return <div className="edu-back-white" id="forum_index_list"></div>
    }
    current_user.user_url = `/users/${current_user.login}`;
    const isCurrentUserTheAuthor = current_user.login == memo.author.login
    const isAdmin = this.props.isAdmin()
    // TODO 图片上传地址
    const courseId = this.props.match.params.coursesId;
    const boardId = this.props.match.params.boardId;
    const isCourseEnd = this.props.isCourseEnd();

    document.title = this.props.coursedata && this.props.coursedata.name;
    return (
      <div className="edu-back-white edu-class-container edu-position course-message topicDetail" id="yslforum_index_list"> {/* fl with100 */}
        <style>{`
            .topicDetail #forum_list .return_btn.no_mr {
              margin-right: 1px;
            }
            /* 有内容时，编辑器下方的边框*/
            .topicDetail .borderBottom.commentInputs {
              border-bottom: 1px solid rgb(238, 238, 238);
            }
            .independent {
              background: rgb(250, 250, 250);
              padding-bottom: 20px;
              margin-bottom: 0px !important;
            }

            .course-message.topicDetail .panel-comment_item .comment_orig_content {
                width: 1072px;
            }
          `}</style>
        <CBreadcrumb className={'independent'} items={[
          { to: current_user && current_user.first_category_url, name: this.props.coursedata.name },
          { to: `/classrooms/${courseId}/boards/${boardId}`, name: memo.board_name },
          { name: '帖子详情' }
        ]}></CBreadcrumb>

        <SendToCourseModal
          ref="sendToCourseModal"
          {...this.props}
          moduleName="帖子"
          seletedMessageIds={[messageId]}
        ></SendToCourseModal>
        <div className="clearfix">
          <div id="forum_list" className="forum_table mh650">
            <div className="padding30 bor-bottom-greyE" style={{ paddingBottom: '20px' }}>
              <div className="font-16 cdefault clearfix pr pr35">
                <span className="noteDetailTitle">{memo.subject}</span>
                {!!memo.sticky && <span className="btn-cir btn-cir-red ml10"
                  style={{ position: 'relative', bottom: '4px' }}>置顶</span>}
                {!!memo.reward && <span className="color-orange font-14 ml15"
                  data-tip-down={`获得平台奖励金币：${memo.reward}`} >
                  <i className="iconfont icon-gift mr5"></i>{memo.reward}
                </span>}
                {/* || current_user.user_id === author_info.user_id */}
                {current_user && (isAdmin || isCurrentUserTheAuthor) &&
                  <div className="edu-position-hidebox" style={{ position: 'absolute', right: '2px', top: '4px' }}>
                    <a href="javascript:void(0);"><i className="fa fa-bars font-16"></i></a>
                    <ul className="edu-position-hide undis">

                      {(isCurrentUserTheAuthor || isAdmin) &&
                        <li><a
                          onClick={() => this.props.toEditPage(Object.assign({}, this.props.match.params, { 'coursesId': this.state.memo.course_id }))}
                        >编&nbsp;&nbsp;辑</a></li>}
                      {isAdmin &&
                        (memo.sticky == true ?
                          <li><a href="javascript:void(0);" onClick={() => this.setTop(memo)}>取消置顶</a></li>
                          :
                          <li><a href="javascript:void(0);" onClick={() => this.setTop(memo)}>置&nbsp;&nbsp;顶</a></li>)
                      }
                      {isAdmin &&
                        <li><a href="javascript:void(0);" onClick={() => this.refs.sendToCourseModal.setVisible(true)}>发&nbsp;&nbsp;送</a></li>
                      }
                      {(isCurrentUserTheAuthor || isAdmin) && <li>
                        <a onClick={() =>
                          window.delete_confirm_box_2_react(`onMemoDelete`, '您确定要删除吗？', memo)}>

                          删&nbsp;&nbsp;除</a>
                      </li>
                      }
                    </ul>
                  </div>
                }

              </div>
              <div className="df mt20">
                <img src={setImagesUrl(`/images/${author && author.image_url}`)} className="radius mr10 mt2" width="40px" height="40px" />
                <div className="flex1">
                  <div className="color-grey-9 lineh-20">
                    <span className="color-grey-3 mr20 fl" style={{ "fontWeight": "400" }}>{author && author.name}</span>
                    <span className="fl">{moment(memo.created_on).fromNow()} 发布</span>
                  </div>

                  <div className="color-grey-9 clearfix">
                    <span className="fl" style={{ marginTop: '4px' }}>
                      <Tooltip title={"浏览数"}>
                        <span className={`noteDetailNum `} style={{ paddingLeft: '0px' }}>
                          <i className="iconfont icon-liulanyan mr5"></i>
                          <span>{memo.visits || '1'}</span>
                        </span>
                      </Tooltip>
                      {!!memo.total_replies_count &&
                        <Tooltip title={"回复数"}>
                          <a className="noteDetailNum">
                            <i className="iconfont icon-huifu1 mr5" onClick={this.showCommentInput}></i>
                            <span>{memo.total_replies_count}</span>
                          </a>
                        </Tooltip>
                      }
                      {!!memo.total_praises_count &&
                        <Tooltip title={"点赞数"}>
                          <span className={`noteDetailNum `} style={{}}>
                            <i className="iconfont icon-dianzan-xian mr5"></i>
                            <span style={{ top: "2px", position: "relative" }}>{memo.total_praises_count}</span>
                          </span>
                        </Tooltip>
                      }
                    </span>
                    <div className="fr">
                      <a className={`task-hide fr return_btn color-grey-6 ${current_user && (isAdmin
                      ) ? '' : 'no_mr'} `} onClick={() => this.props.toListPage(Object.assign({}, this.props.match.params, { 'coursesId': this.state.memo.course_id }))} >
                        返回
                                </a>
                    </div>
                  </div>
                </div>
              </div>
            </div>


            <div className="padding30 memoContent new_li" style={{ paddingBottom: '10px' }}>
              <RenderHtml value={memo.content} />
            </div>
            <div className="padding30 bor-bottom-greyE" style={{ paddingTop: '2px' }}>
              <div className="mt10 mb20">
                <Tooltip title={`${memo.liked ? '取消点赞' : '点赞'}`}>
                  <p className={`noteDetailPoint  ${memo.user_praise ? 'Pointed' : ''}`} onClick={() => { this.clickPraise() }} >
                    <i className="iconfont icon-dianzan"></i><br />
                    <span>{memo.praises_count}</span>
                  </p>
                </Tooltip>
              </div>

              {memo.attachments && !!memo.attachments.length &&
                <div>
                  {this.renderAttachment()}
                </div>
              }
            </div>

            {!isCourseEnd ? <MemoDetailMDEditor active={this.state.active} mid={memo.id} onActive={this.showCommentInput} onCommit={this.replyComment} /> : null}

            <div className="padding20  memoReplies commentsDelegateParent comments_hideSecondReplyUserHeader"
              style={{ display: (comments && !!comments.length) ? 'block' : 'none', paddingBottom: '0px' }}>
              <div className="replies_count commentstypetop">
                {this.props.isAdmin() === true ? <span className="commentstypebutton font-16 ">
                  {this.state.commentstype === false ? <Button type="primary" onClick={() => this.startcomments()}>开启刷新评论</Button>
                    : <Button type="danger" onClick={() => this.clearcomments()}>停止刷新</Button>}
                </span> : ""}

                <span className="labal font-16">全部回复</span>
                <span className="count font-16">({memo.total_replies_count})</span>

              </div>

              <Comments comments={comments} user={current_user}
                replyComment={this.replyComment}
                deleteComment={this.deleteComment}
                commentPraise={this.commentPraise}
                rewardCode={this.rewardCode}
                hiddenComment={this.hiddenComment}
                buttonText={'发表'}

                usingAntdModal={true}
                isChildCommentPagination={true}
                loadMoreChildComments={this.loadMoreChildComments}
                initReply={this.initReply}
                showRewardButton={false}
                showReply={!isCourseEnd}

                onlySuperAdminCouldHide={true}
              ></Comments>
            </div>
            <div className="memoMore" style={{ 'margin-top': '20px' }}>
              {total_count > REPLY_PAGE_COUNT &&
                <Pagination showQuickJumper onChange={this.onPaginationChange} current={pageCount} total={total_count} pageSize={10} />
              }
            </div>

          </div>
        </div>
      </div>

    );
  }
}

export default ImageLayerOfCommentHOC()(RouteHOC()(TopicDetail));
