import React, { Component } from "react";
import axios from "axios";
import { getImageUrl, trigger, on, off } from "educoder";
import { Tooltip, message, Popover, Breadcrumb, Icon } from "antd";
import CoursesListType from "../coursesPublic/CoursesListType";
import AccountProfile from "../../user/AccountProfile";
import Addcourses from "../coursesPublic/Addcourses";
import "../css/Courses.css";
import Modals from "../../modals/Modals";
import SwitchModals from "../../modals/SwitchModel"
import Jointheclass from "../../modals/Jointheclass";
import Certifiedprofessional from "../../modals/Certifiedprofessional";
import "./course-banner.css";
import styled from "styled-components";
import BannerImg from "./banner/courseBanner.png";
import Addusermodal from "../members/modal/AddUserModal";
import {
  AddStudentIcon,
  AddTutorIcon,
  AddTeacherIcon,
  TeacherIcon,
  StudentIcon,
} from "./banner/icon.js";

const Setting = styled(Icon).attrs((p) => ({
  type: "setting",
}))`
  color: white;
  display: inline-block;
  margin-left: 10px;
  & :hover {
    cursor: pointer;
  }
`;

const DecoLine = styled.div`
  width: 1px;
  height: 11px;
  background: rgba(255, 255, 255, 1);
  opacity: 0.3;
  margin: 0 8px;
`;

const WrappedBreadcrumb = styled(Breadcrumb)`
  & .ant-breadcrumb-separator {
    color: rgba(255, 255, 255, 0.3);
  }
  & .ant-tooltip-inner {
    background: white;
  }
  & .ant-tooltip-arrow::before {
    background: white;
  }
`;

const BetweenBox = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
`;

const ABtn = styled.a`
  width: 106px;
  height: 30px;
  display: block;
  background: rgba(77, 172, 255, 1);
  border-radius: 15px;
  text-align: center;
  line-height: 30px;
  font-size: 14px;
  font-family: "Helvetica Neue", Helvetica, "PingFang SC", "Hiragino Sans GB",
    "Microsoft YaHei", "微软雅黑", Arial, sans-serif;
  font-weight: 400;
  color: rgba(255, 255, 255, 1);
  letter-spacing: 1px;
  & :hover {
    cursor: pointer;
  }
  margin-bottom: 5px;
`;

const Bg = styled.div`
  height: 245px;
  background: url(${BannerImg});
  background-size: cover;
  background-position: center;
  background-repeat: no-repeat;
`;

const AutoBox = styled.div`
  width: 1200px;
  margin: 0 auto;
  height: 245px;
  display: flex;
  flex-direction: column;
  & > ${BetweenBox}:last-child {
    padding: 0 16px;
    height: 60px;
    background: rgba(70, 85, 114, 1);
    border-radius: 4px 4px 0px 0px;
    opacity: 0.95;
  }
`;

const Deco = styled.div`
  width: 1180px;
  margin: 0 auto;
  height: 7px;
  background: linear-gradient(
    117deg,
    rgba(49, 65, 96, 1) 0%,
    rgba(52, 69, 104, 1) 50%,
    rgba(56, 71, 100, 1) 100%
  );
  border-radius: 4px 4px 0px 0px;
  opacity: 0.97;
`;

const ButtomFont = styled.span`
  font-size: 14px;
  font-family: "Helvetica Neue", Helvetica, "PingFang SC", "Hiragino Sans GB",
    "Microsoft YaHei", "微软雅黑", Arial, sans-serif;
  font-weight: 300;
  color: rgba(255, 255, 255, 1);
  letter-spacing: 1px;
  & :hover {
    cursor: pointer;
  }
`;

const HeadFont = styled.div`
  font-size: 12px;
  font-family: "Helvetica Neue", Helvetica, "PingFang SC", "Hiragino Sans GB",
    "Microsoft YaHei", "微软雅黑", Arial, sans-serif;
  font-weight: 300;
  color: rgba(208, 219, 240, 1);
  letter-spacing: 1px;
`;

const Name = styled.div`
  font-size: 24px;
  font-family: "Helvetica Neue", Helvetica, "PingFang SC", "Hiragino Sans GB",
    "Microsoft YaHei", "微软雅黑", Arial, sans-serif;
  font-weight: 400;
  color: rgba(255, 255, 255, 1);
  letter-spacing: 1px;
`;

const TeacherName = styled.div`
  font-size: 14px;
  font-family: "Helvetica Neue", Helvetica, "PingFang SC", "Hiragino Sans GB",
    "Microsoft YaHei", "微软雅黑", Arial, sans-serif;
  font-weight: 400;
  color: rgba(255, 255, 255, 1);
  letter-spacing: 1px;
  margin-left: 5px;
`;
const TeacherSchool = styled.div`
  font-size: 12px;
  font-family: "Helvetica Neue", Helvetica, "PingFang SC", "Hiragino Sans GB",
    "Microsoft YaHei", "微软雅黑", Arial, sans-serif;
  font-weight: 400;
  color: rgba(255, 255, 255, 1);
  letter-spacing: 1px;
  margin-left: 5px;
`;



function codesuccess() {
  message.success("复制成功");
}

class CoursesBanner extends Component {
  constructor(props) {
    super(props);
    this.state = {
      show: false,
      Addcoursestypes: false,
      modalsType: false,
      modalsTopval: "",
      loadtype: false,
      metype: 0,
      modalsBottomval: "",
      antIcon: false,
      coursedata: undefined,
      is_guide: false,
      excellent: false, //是否是精品课堂
      yslJointhe: false,
      mydisplay: false,
      yslJointhes: false,
      modelType:"",
      switchtype:0,
    };
  }
  componentDidMount() {
    this.onloadupdatabanner();
    on("updatabanner", this.updatabanner);
    if (this.props.match.path === "/classrooms/:coursesId") {
      if (this.props.user != undefined) {
        this.props.history.push(this.props.user.first_category_url);
      }
    }
    axios.interceptors.response.use(
      (response) => {
        if (response != undefined)
          if (response && response.data.status === 410) {
            this.setState({
              yslJointhe: true,
              yslJointhes: true,
            });
          }
        return response;
      },
      (error) => {}
    );
  }
  // 点击按钮复制功能
 jsCopy=()=>{
  var e = document.getElementById("copy_invite_code");
  e.select();
  document.execCommand("Copy");
  codesuccess();
}
  componentDidUpdate(prevProps) {
    if (prevProps.user != this.props.user) {
      if (this.props.match.path === "/classrooms/:coursesId") {
        if (this.props.user != undefined) {
          this.props.history.push(this.props.user.first_category_url);
        }
      }
    }
  }
  componentWillUnmount() {
    off("updatabanner", this.updatabanner);
  }

  HideAddcoursestypess = (i) => {
    this.setState({
      Addcoursestypes: false,
      mydisplay: true,
      occupation: i,
    });
  };
  ModalCancelsy = () => {
    this.setState({
      mydisplay: false,
    });
  };

  onloadupdatabanner = () => {
    this.updatabanner();
  };
  updatabanner = () => {
    const query = this.props.location.search;
    var dataqueryss = {};
    try {
      var foqus = this.foo(query);
      if (JSON.stringify(foqus) === "{}") {
        this.setState({
          dataquerys: {},
        });
      } else {
        this.setState({
          dataquerys: foqus,
        });
        dataqueryss = foqus;
      }
    } catch (e) {
      this.setState({
        dataquerys: {},
      });
    }
    let courseId = this.props.match.params.coursesId;
    let url = "/courses/" + courseId + "/top_banner.json";
    axios
      .get(url, {
        params: dataqueryss,
      })
      .then((result) => {
        try {
          if (result.data.status === -2) {
          } else {
            if (result != undefined) {
              let data = result.data;
              this.setState({
                coursedata: data,
                excellent: data.excellent,
              });
              this.props.ispostexcellenttype(data.excellent);
            } else {
              this.onloadupdatabanner();
            }
          }
        } catch (e) {}
      });
  };
  foo = (url) => {
    var json = {};
    var regExp = /[\?\&](\w+)(=?)(\w*)/g;
    var arr;
    do {
      arr = regExp.exec(url);

      if (arr) {
        var key = arr[1];
        var value = arr[3];
        if (!arr[2]) value = undefined;

        json[key] = value;
      }
    } while (arr);

    return json;
  };

  tojoinclass = (val) => {
    if (
      this.props.current_user &&
      this.props.current_user.profile_completed === false
    ) {
      this.setState({
        AccountProfiletype: true,
      });
      return;
    }

    if (val === 1) {
      this.setState({
        Addcoursestypes: true,
      });
    } else {
      this.setState({
        Addcoursestypes: false,
      });
    }
  };

  //精品课堂的弹框
  myyslgradin = () => {
    this.setState({
      yslJointhe: true,
    });
  };
  showActionPoll = (i, s, ss, trs) => {
    this.setState({
      modalsType: true,
      modalsTopval: s,
      loadtype: false,
      metype: i,
      modalsBottomval: ss,
      modalstrsvalue: trs,
    });
  };
  ActionPoll = (i) => {
    let { coursedata } = this.state;
    var s = "";
    var ss = "";
    if (i === 1) {
      s = "课堂删除后数据将无法恢复，是否确定删除？";
      this.showActionPoll(i, s);
    }
    if (i === 2) {
      s = "您确定要设置为私有?";
      this.showActionPoll(i, s);
    }
    if (i === 3) {
      s = "设为公开后，非课堂成员也可以访问查看";
      ss = "是否确认设为公开？";
      this.showActionPoll(i, s, ss);
    }

    if (i === 4) {
      if (coursedata.code_halt === true) {
        var url = `/courses/${this.props.match.params.coursesId}/set_invite_code_halt.json`;
        axios.post(url, {}).then((result) => {
          try {
            if (result.data.status === 0) {
              this.updatabanner();
            }
          } catch (e) {}
        });
      } else {
        s = "课堂邀请码停用后，用户不能主动加入该课堂了";
        ss = "您是否确认停用?";
        this.showActionPoll(i, s, ss);
      }
    }
    if (i === 5) {
      s = `“复制”功能将会为您创建一个新的课堂`;
      ss = "请问是否继续？";
      let mid = "旧课堂的作业、资源、试卷等都将被复制到新的课堂里面";
      this.showActionPoll(i, s, ss, mid);
    }
  };
  //取消
  modalCancel = () => {
    this.setState({
      modalsType: false,
      modalsTopval: "",
      modalsBottomval: "",
      loadtype: false,
      antIcon: false,
      modalstrsvalue: undefined,
    });
  };
  // 确定
  ModalAction = () => {
    let { coursedata } = this.state;
    let that = this;
    var push = this.props.history;
    let id = this.props.match.params.coursesId;
    //删除
    if (this.state.metype === 1) {
      that.setState({
        antIcon: true,
      });

      var url = `/courses/${id}.json`;
      axios.delete(url, {}).then(function (response) {
        if (response.data.status === 0) {
          that.setState({
            antIcon: false,
          });
          that.modalCancel();
          message.success("删除成功", 1);
          push.push(`/classrooms`);
        }
      });
    }
    //设为私有的
    if (this.state.metype === 2) {
      this.modalCancel();
      var state = this.state;
      var url = `/courses/${id}/set_public_or_private.json`;
      axios.post(url, {}).then((result) => {
        if (result.data.status === 0) {
          message.success("设为私有的成功", 1);
          state.coursedata.is_public = false;
          this.setState({
            coursedata: state.coursedata,
          });
        }
      });
    }
    //设为公有的
    if (this.state.metype === 3) {
      this.modalCancel();
      var state = this.state;
      var url = `/courses/${id}/set_public_or_private.json`;
      axios.post(url, {}).then((result) => {
        if (result.data.status === 0) {
          message.success("设为公有的成功", 1);
          state.coursedata.is_public = true;
          this.setState({
            coursedata: state.coursedata,
          });
        }
      });
    }
    //停用邀请码
    if (this.state.metype === 4) {
      this.modalCancel();
      var url = `/courses/${id}/set_invite_code_halt.json`;
      axios.post(url, {}).then((result) => {
        try {
          if (result.data.status === 0) {
            message.success(
              coursedata.code_halt === true
                ? "启用用邀请码成功"
                : "停用邀请码成功",
              1
            );
            this.updatabanner();
          }
        } catch (e) {}
      });
    }
    if (this.state.metype === 5) {
      this.setState({
        antIcon: true,
      });
      var url = `/courses/${id}/duplicate_course.json`;
      axios
        .post(url)
        .then((response) => {
          if (response !== undefined) {
            window.location.href =
              "/classrooms/" + response.data.new_course_id + "/students";
            return;
          }
          this.modalCancel();
        })
        .catch((error) => {
          this.modalCancel();
          console.log(252);
          console.log(error);
        });
    }
    // 退出课堂
    if (this.state.metype === 6) {
      this.setState({
        antIcon: true,
      });
      var url = `/courses/${id}/exit_course.json`;
      axios.post(url).then((response) => {
        if (response.data.status === 0) {
          window.location.href = "/users/" + this.props.current_user.login;
        }
      });
    }
  };
  addTeacher = (type) => {
    this.setState({
      modelType: type === "添加学生" ? 1 : type === "添加老师" ? 2 : 3,
    });
    this.refs.addusermodal.setshowmodel(true);
  };
  addStudent = () => {
    this.refs.addStudentModal.setVisible(true);
  };
  addTeacherSuccess = (params) => {
    trigger("addTeacherSuccess", JSON.stringify(params));
    this.updatabanner();
  };
  addStudentSuccess = (params) => {
    trigger("addStudentSuccess", JSON.stringify(params));
    this.updatabanner();
  };
  adduser = (data, type) => {
    //先进行判断 如果没有选择用户 添加提示选择用户
    const courseId = this.props.match.params.coursesId;
    let params;
    let url;
    if (type > 1) {
      url = `/courses/${courseId}/add_teacher.json`;
      params = {
        user_list: data.map((item) => {
          return { user_id: item };
        }),
        role: type,
      };
    } else {
      url = `/courses/${courseId}/add_students_by_search.json`;
      params = {
        user_ids: data,
        course_group_id: "0",
      };
    }

    axios
      .post(url, params)
      .then((result) => {
        if (result) {
          this.props.showNotification("添加成功");
          this.refs.addusermodal.setshowmodel(false);
        }
      })
      .catch(function (error) {
        console.log(error);
      });
  };

  //退出课堂按钮
  exitclass = () => {
    this.setState({
      modalsType: true,
      modalsTopval: "退出后您将不再是本课堂的成员,作品将全部被删除，",
      modalsBottomval: "",
      metype: 6,
    });
  };

  //加入分班J
  switchtype=(course_group_id,type)=>{
    let newurl = this.props.match.url;

    if(type===1){
      let id = this.props.match.params.coursesId;
      let url=`/courses/${id}/switch_to_student.json`
      axios.post(url,{
        course_group_id:course_group_id
      }).then((response) => {
        if (response != undefined) {
          if (response.data.status === 0) {
            window.location.href = newurl;
          }
        }
      });
    }else if(type===2){
      this.switchidentity(type)
    }else{
      this.switchidentity(type)
    }
  }

  //新增提示弹窗 
  showmodel=(sum)=>{
    if(sum===1){
      this.setState({
        switchtype: 1,
        modalsTopval: "如果分班单独设置发布内容（实训作业、普通作业、试卷等）， 需要加入分班才能查看",
      });
      this.refs.showmodel.setmodels(true);
    }else if(sum===2){
      this.setState({
        switchtype: 2,
        modalsTopval: "由学生身份切换至教师，拥有添加成员、发布作业等管理权限",
      });
      this.refs.showmodel.setmodels(true);
    }else{
      this.setState({
        switchtype: 3,
        modalsTopval: "由学生身份切换至助教，拥有添加成员、发布作业等管理权限",
      });
      this.refs.showmodel.setmodels(true);
    }
  }


  //切换身份
  switchidentity = (sum) => {
    let newurl = this.props.match.url;
    let id = this.props.match.params.coursesId;
    let url;
    if(sum===1){
       url=`/courses/${id}/switch_to_student.json`;
    }else if(sum===2){
       url = `/courses/${id}/switch_to_teacher.json`;
    }else{
       url = `/courses/${id}/switch_to_assistant.json`;
    }
    axios.post(url).then((response) => {
      if (response != undefined) {
        if (response.data.status === 0) {
          window.location.href = newurl;
        }
      }
    });
  };
  postsettings = () => {
    window.location.href =
      "/classrooms/" + this.props.match.params.coursesId + "/settings";
  };
  postsettingstwo = () => {
    window.location.href = `/classrooms/${this.props.match.params.coursesId}/newgolds/settings`;
  };

  hideAccountProfile = () => {
    this.setState({
      AccountProfiletype: false,
      content: undefined,
      okText: undefined,
      okHref: undefined,
      cannelText: undefined,
      Accounturltype: undefined,
    });
  };
  ysljoinmodalCancel = () => {
    this.setState({
      yslJointhe: false,
    });
    if (this.state.yslJointhes === true) {
      window.location.href = "/";
    }
  };
  ysljoinmodalCanceltwo = () => {
    this.setState({
      yslJointhe: false,
    });
    window.location.reload();
  };

  setHistoryFun = (url) => {
    this.updatabanner();
    this.props.history.replace(url);
  };

  render() {
    let {
      Addcoursestypes,
      coursedata,
      excellent,
      modalsType,
      modalsTopval,
      loadtype,
      modalsBottomval,
      antIcon,
      is_guide,
      AccountProfiletype,
      modalstrsvalue,
    } = this.state;

    const isCourseEnd = this.props.isCourseEnd();
    document.title =
      coursedata === undefined ||
      coursedata.status === 401 ||
      coursedata.status === 407
        ? ""
        : coursedata.name;

    return (
      <Bg>
        {AccountProfiletype === true ? (
          <AccountProfile
            hideAccountProfile={() => this.hideAccountProfile()}
            {...this.props}
            {...this.state}
          />
        ) : null}

        {coursedata === undefined || coursedata.status === 401 ? (
          <div id="course_info_1309"></div>
        ) : (
          <div id="course_info_1309">
            {Addcoursestypes === true ? (
              <Addcourses
                Addcoursestype={Addcoursestypes}
                hideAddcoursestype={() => this.tojoinclass(2)}
                HideAddcoursestypess={(i) => this.HideAddcoursestypess(i)}
              />
            ) : null}
            <Certifiedprofessional
              {...this.props}
              {...this.state}
              ModalCancelsy={this.ModalCancelsy}
            />
            <Modals
              modalsType={modalsType}
              modalsTopval={modalsTopval}
              loadtype={loadtype}
              modalsBottomval={modalsBottomval}
              modalsMidval={modalstrsvalue}
              modalCancel={this.modalCancel}
              modalSave={this.ModalAction}
              antIcon={antIcon}
            ></Modals>
            <SwitchModals switchtype={this.switchtype} switchid={this.props.match.params.coursesId} ref='showmodel' modalsType={this.state.switchtype} modelcount={this.state.modalsTopval} />
            <Jointheclass
              {...this.props}
              {...this.state}
              ysljoinmodalCancel={() => this.ysljoinmodalCancel()}
              ysljoinmodalCanceltwo={() => this.ysljoinmodalCanceltwo()}
            ></Jointheclass>
            {/* <AddTeacherModal
              ref="addTeacherModal"
              {...this.props}
              isTeacher={this.state.isTeacher}
              moduleName={this.state.isTeacher ? "教师" : "助教"}
              addTeacherSuccess={this.addTeacherSuccess}
            ></AddTeacherModal> */}
            <Addusermodal
              ref="addusermodal"
              {...this.props}
              title={this.state.modelType}
              isone={true}
              container_id={this.props.match.params.coursesId}
              container_type={1}
              Ok={this.adduser}
              width={"1100px"}
            ></Addusermodal>
            {/* <AddStudentModal
              ref="addStudentModal"
              {...this.props}
              moduleName="学生"
              addStudentSuccess={this.addStudentSuccess}
            ></AddStudentModal> */}
            <AutoBox>
              <BetweenBox
                style={{
                  marginTop: "30px",
                  marginLeft: "10px",
                  marginRight: "10px",
                }}
              >
                <div>
                  <div style={{ display: "flex", alignItems: "center" }}>
                    {coursedata === undefined ||
                    coursedata.status === 401 ||
                    coursedata.status === 407 ? (
                      ""
                    ) : (
                      <Tooltip
                        placement="bottom"
                        title={
                          coursedata &&
                          coursedata.name &&
                          coursedata.name.length < 38
                            ? ""
                            : coursedata.name
                        }
                      >
                        <Name>{coursedata.name}</Name>
                      </Tooltip>
                    )}
                    <div>
                      {excellent === true ? (
                        <CoursesListType typelist={["开放课程"]} />
                      ) : (
                        ""
                      )}
                      <CoursesListType
                        typelist={
                          coursedata.course_end === true
                            ? ["已结束"]
                            : coursedata.is_public === true
                            ? ["公开"]
                            : ["私有"]
                        }
                        tipval={
                          coursedata.is_public === true
                            ? ""
                            : "私有课堂，非课堂成员不能访问"
                        }
                      />
                    </div>
                  </div>
                  <div style={{ display: "flex", alignItems: "center" }}>
                    {console.log(coursedata)}
                    {coursedata.credit ? (
                      <HeadFont>学分:{coursedata.credit}</HeadFont>
                    ) : (
                      ""
                    )}
                    {coursedata.credit || coursedata.class_period ? (
                      <div
                        style={{
                          borderLeft: "1px solid  #D0DBF0",
                          margin: "0 10px",
                          height: "14px",
                          display: "none",
                        }}
                      ></div>
                    ) : (
                      ""
                    )}
                    {coursedata.credit && coursedata.class_period ? (
                      <DecoLine />
                    ) : (
                      ""
                    )}
                    {coursedata.class_period ? (
                      <HeadFont>学时:{coursedata.class_period}</HeadFont>
                    ) : (
                      ""
                    )}
                  </div>
                </div>
                <div style={{ display: "flex", alignItems: "center" }}>
                  {coursedata.course_identity < 6 ? ( //非课堂成员不出现邀请码
                    <div style={{ display: "flex", alignItems: "center" }}>
                      {excellent === false ? (
                        <React.Fragment>
                          <div
                            style={{
                              color: "rgba(255,255,255,1)",
                              fontSize: "14px",
                            }}
                          >
                            邀请码：
                          </div>
                          <div
                            style={
                              coursedata.code_halt === true
                                ? {
                                    color: "rgba(255,255,255,1)",
                                    fontSize: "14px",
                                  }
                                : { color: "#FED218", fontSize: "14px" }
                            }
                          >
                            {coursedata.code_halt === true ? (
                              <div style={{ marginRight: "10px" }}>已停用</div>
                            ) : (
                              coursedata.invite_code
                            )}
                            {coursedata.code_halt === true ? (
                              ""
                            ) : (
                              <Tooltip
                                placement="bottom"
                                title={
                                  coursedata.code_halt === true ? (
                                    <pre>
                                      邀请码已停用
                                      <br />
                                      成员不能主动加入课堂
                                    </pre>
                                  ) : (
                                    <pre>
                                      成员可以通过邀请码主动加入课堂
                                      <br />
                                      点击立刻复制邀请码
                                    </pre>
                                  )
                                }
                              >
                                <i
                                  className="iconfont icon-fuzhi color-white font-14"
                                  onClick={this.jsCopy}
                                  style={{
                                    display: "inline-block",
                                    marginLeft: "5px",
                                    marginRight: "10px",
                                  }}
                                ></i>
                              </Tooltip>
                            )}
                            <input
                              id="copy_invite_code"
                              value={coursedata.invite_code}
                              style={{opacity: '0',position: 'absolute',bottom:"15px"}}
                            />                            
                          </div>
                        </React.Fragment>
                      ) : null}
                    </div>
                  ) : null}
                
                  {coursedata.course_identity>1&&coursedata.course_identity<6?<span style={{color:'#ffffff',marginLeft:'10px',marginRight:'10px'}}>当前身份：{coursedata.course_identity>1&&coursedata.course_identity<4?'老师':coursedata.course_identity===4?'助教':'学生'}</span>:''}
                  <div
                    style={{
                      width: "1px",
                      height: "11px",
                      background: "rgba(255,255,255,1)",
                      opacity: "0.3",
                    }}
                  />
                  {coursedata.course_identity < 6 ||
                  (this.props.user && this.props.user.is_teacher) ? (
                    <div>
                      <Popover
                        placement="bottom"
                        className="settingBtns"
                        content={
                          excellent === false ? (
                            <ul
                              className="sandianbox"
                              style={{
                                display: "block",
                                right: "-113px",
                                top: "20px",
                              }}
                            >
                              {coursedata.switch_to_student === true ? (
           
                                <div
                                  className="defaults"
                                  onClick={() => this.showmodel(1)}
                                >
                                  切换为学生
                                </div>
                              ) : null}

                              {coursedata.switch_to_teacher === true ? (
              
                                <div
                                  className="defaults"
                                  onClick={() => this.showmodel(2)}
                                >
                                  切换为老师
                                </div>
                              ) : (
                                ""
                              )}

                              {coursedata.switch_to_assistant === true ? (
            
                                <div
                                  className="defaults"
                                  onClick={() => this.showmodel(3)}
                                >
                                  切换为助教
                                </div>
                              ) : (
                                ""
                              )}
                              {coursedata.is_public === true ? (
                                coursedata.course_identity < 3 ? (
                                  <div
                                    className={"defaults"}
                                    onClick={() => this.ActionPoll(2)}
                                  >
                                    设为私有
                                  </div>
                                ) : null
                              ) : null}

                              {coursedata.is_public === false ? (
                                coursedata.course_identity < 3 ? (
                                  <div
                                    className={"defaults"}
                                    onClick={() => this.ActionPoll(3)}
                                  >
                                    设为公开
                                  </div>
                                ) : null
                              ) : null}

                              {coursedata.course_identity < 3 ? (
                                <div
                                  className={"defaults"}
                                  onClick={() => this.ActionPoll(4)}
                                >
                                  {coursedata.code_halt === true
                                    ? "启用邀请码"
                                    : "停用邀请码"}
                                </div>
                              ) : null}
                              {coursedata.course_identity < 5 ? ( //非课堂成员不出现【编辑课堂】
                                <div
                                  className={"defaults"}
                                  onClick={() =>
                                    this.props.history.push(
                                      `/classrooms/${this.props.match.params.coursesId}/settings`
                                    )
                                  }
                                >
                                  编辑课堂
                                </div>
                              ) : null}
                              {coursedata.course_identity < 5 ||
                              (this.props.user &&
                                this.props.user.is_teacher) ? ( //复制课堂只有超管、运营、教师、专业人士身份可以出现
                                <div
                                  className={"defaults"}
                                  onClick={() => this.ActionPoll(5)}
                                >
                                  复制
                                </div>
                              ) : null}

                              {coursedata.is_admin === true ? (
                                coursedata.course_identity < 3 ? (
                                  <div
                                    className={"defaults"}
                                    onClick={() => this.ActionPoll(1)}
                                  >
                                    删除
                                  </div>
                                ) : null
                              ) : null}
                              {this.props.isStudent() ? (
                                this.props.current_user &&
                                this.props.current_user.course_is_end ===
                                  true ? null : (
                                  <div
                                    className="defaults"
                                    onClick={() => this.exitclass()}
                                  >
                                    退出课堂
                                  </div>
                                )
                              ) : null}
                            </ul>
                          ) : (
                            <ul
                              className="sandianbox"
                              style={{
                                display: "block",
                                right: "-113px",
                                top: "20px",
                              }}
                            >
                              <div
                                className={"defaults"}
                                onClick={this.postsettingstwo}
                              >
                                编辑课堂
                              </div>
                              {coursedata.is_admin === true ? (
                                coursedata.course_identity < 3 ? (
                                  <div
                                    className={"defaults"}
                                    onClick={() => this.ActionPoll(1)}
                                  >
                                    删除
                                  </div>
                                ) : null
                              ) : null}
                            </ul>
                          )
                        }
                        trigger="hover"
                      >
                        <Setting />
                      </Popover>
                    </div>
                  ) : null}
                </div>
              </BetweenBox>
              <BetweenBox
                style={{
                  marginTop: "24px",
                  marginLeft: "10px",
                  marginRight: "10px",
                }}
              >
                <div style={{ display: "flex" }}>
                  <div>
                    <a href={"/users/" + coursedata.teacher_login}>
                      <img
                        alt="头像"
                        className="radius bannerimgname"
                        src={getImageUrl(`images/` + coursedata.teacher_img)}
                      />
                    </a>
                  </div>
                  <div>
                    <TeacherName
                      onClick={() =>
                        this.props.history.push(
                          "/users/" + coursedata.teacher_login
                        )
                      }
                    >
                      {coursedata.teacher_name}
                    </TeacherName>
                    <TeacherSchool>{coursedata.teacher_school}</TeacherSchool>
                  </div>
                </div>
                <div>
                  {coursedata.course_identity === 6 &&
                  coursedata.educoder_teacher === false ? (
                    excellent === false ? (
                      <ABtn
                        id="shixun_operation"
                        onClick={() => this.tojoinclass(1)}
                      >
                        加入课堂
                      </ABtn>
                    ) : (
                      <ABtn
                        id="shixun_operation"
                        onClick={() => this.myyslgradin(1)}
                      >
                        立即加入
                      </ABtn>
                    )
                  ) : (
                    ""
                  )}

                  {coursedata.course_identity === 6 &&
                  coursedata.educoder_teacher === true ? (
                    excellent === false ? (
                      <ABtn
                        id="shixun_operation"
                        onClick={() => this.tojoinclass(1)}
                      >
                        加入课堂
                      </ABtn>
                    ) : (
                      <ABtn
                        id="shixun_operation"
                        onClick={() => this.myyslgradin(1)}
                      >
                        立即加入
                      </ABtn>
                    )
                  ) : (
                    ""
                  )}

                  {/* {coursedata.course_identity === 6 &&
                  coursedata.educoder_teacher === true ? (
                    excellent === false ? (
                      <ABtn onClick={() => this.ActionPoll(5)}>复制课堂</ABtn>
                    ) : null
                  ) : null} */}
                </div>
              </BetweenBox>
              <div style={{ flex: "1" }} />
              <Deco />
              <BetweenBox>
                <div>
                  <WrappedBreadcrumb separator="|">
                    <Breadcrumb.Item
                      className={
                        excellent && !this.props.isAdminOrStudent()
                          ? ""
                          : "pointer"
                      }
                    >
                      <Tooltip
                        getPopupContainer={(trigger) => trigger.parentNode}
                        visible={
                          excellent === true &&
                          this.props.isAdminOrStudent() === false
                            ? false
                            : coursedata.teacher_applies_count === undefined
                            ? false
                            : coursedata.teacher_applies_count > 0
                            ? true
                            : false
                        }
                        placement="top"
                        title={
                          <div>
                            {coursedata.teacher_applies_count &&
                            coursedata.teacher_applies_count > 0 ? (
                              <span style={{ color: "black" }}>
                                新收到{coursedata.teacher_applies_count}
                                条加入课堂的申请&nbsp;&nbsp;
                                <a
                                  className={"daishenp"}
                                  onClick={
                                    excellent && !this.props.isAdminOrStudent()
                                      ? undefined
                                      : () =>
                                          this.setHistoryFun(
                                            "/classrooms/" +
                                              this.props.match.params
                                                .coursesId +
                                              "/teachers?tab=2"
                                          )
                                  }
                                >
                                  <span style={{ color: "#FFA804" }}>
                                    去审批
                                  </span>
                                </a>
                              </span>
                            ) : (
                              ""
                            )}
                          </div>
                        }
                      >
                        <ButtomFont
                          onClick={
                            excellent && !this.props.isAdminOrStudent()
                              ? undefined
                              : () =>
                                  this.setHistoryFun(
                                    `/classrooms/${this.props.match.params.coursesId}/teachers`
                                  )
                          }
                        >
                          <Icon component={TeacherIcon} />
                          &nbsp;教师&nbsp;{coursedata.teacher_count}
                        </ButtomFont>
                      </Tooltip>
                    </Breadcrumb.Item>

                    <Breadcrumb.Item
                      className={
                        excellent === true &&
                        this.props.isAdminOrStudent() === false
                          ? ""
                          : excellent === true && coursedata.course_end === true
                          ? this.props.isAdminOrTeacher() === true
                            ? "pointer"
                            : ""
                          : "pointer"
                      }
                      onClick={
                        excellent === true &&
                        this.props.isAdminOrStudent() === false
                          ? ""
                          : excellent === true && coursedata.course_end === true
                          ? this.props.isAdminOrTeacher() === true
                            ? () =>
                                this.setHistoryFun(
                                  "/classrooms/" +
                                    this.props.match.params.coursesId +
                                    "/students"
                                )
                            : ""
                          : () =>
                              this.setHistoryFun(
                                "/classrooms/" +
                                  this.props.match.params.coursesId +
                                  "/students"
                              )
                      }
                    >
                      <ButtomFont>
                        <Icon component={StudentIcon} />
                        &nbsp;学生&nbsp;{coursedata.student_count}
                      </ButtomFont>
                    </Breadcrumb.Item>
                  </WrappedBreadcrumb>
                </div>
                <div>
                  {this.props.isAdmin() && !isCourseEnd ? (
                    <div style={{ display: "flex", alignItems: "center" }}>
                      <a>
                        <ButtomFont onClick={() => this.addTeacher("添加老师")}>
                          <Icon component={AddTeacherIcon} />
                          &nbsp;添加老师
                        </ButtomFont>
                      </a>
                      <DecoLine />
                      <a>
                        <ButtomFont onClick={() => this.addTeacher("添加助教")}>
                          <Icon component={AddTutorIcon} />
                          &nbsp;添加助教
                        </ButtomFont>
                      </a>
                      <DecoLine />
                      <a>
                        <ButtomFont onClick={() => this.addTeacher("添加学生")}>
                          <Icon component={AddStudentIcon} />
                          &nbsp;添加学生
                        </ButtomFont>
                      </a>
                    </div>
                  ) : null}
                </div>
              </BetweenBox>
            </AutoBox>
          </div>
        )}
      </Bg>
    );
  }
}

export default CoursesBanner;
