//padding 24px
import React, { useReducer, createContext, useEffect } from "react";
import { useLoaded, useParams, useDebounceState } from "../util/hooks";
import { Pagination } from "../util/widget";
import { BetweenBox, FlexBox, AllCenter } from "../util/layout";
import update from "immutability-helper";
import axios from "axios";
import {
  LstHead,
  LstItem,
  FGroup,
  SearchBar,
  Count,
  Action,
  SFilter,
} from "./lst";
import { Content, Row } from "./style";
import _ from "lodash";
import { haveSub, haveObj } from "./lst/util";
import { Empty, Spin } from "antd";

const cfg = {
  order_type: undefined,
  order: undefined,
  commit_status: undefined,
  review: undefined,
  exercise_group_id: undefined,
  objective_score_gte: undefined,
  objective_score_lte: undefined,
  search: undefined,
  page: 1,
};

export const UpdateCtx = createContext(null);
export const InfoCtx = createContext(null);

export default (props) => {
  const { Id: exerciseId } = useParams();
  const [filterCfg, dispatch] = useReducer((state, action) => {
    if (action.type == "sort") {
      return update(state, {
        order: { $set: action.payload.order },
        order_type: { $set: action.payload.order_type },
      });
    }
    return update(state, {
      [action.type]: { $set: action.payload },
    });
  }, cfg);
  const [_filterCfg, setDebounce] = useDebounceState(filterCfg, 500);
  useEffect(() => {
    setDebounce(filterCfg);
  }, [filterCfg]);
  const { isLoaded, data } = useLoaded(async () => {
    if (exerciseId) {
      let url = `/exercises/${exerciseId}/exercise_lists.json`;
      return (await axios.get(url, { params: _filterCfg })).data;
    }    
  }, [_filterCfg, exerciseId]);
  if (!data) {
    return <Spin spinning={true} size="large" style={{width:'100%'}}></Spin>;
  }
  return (
    <UpdateCtx.Provider value={dispatch}>
      <InfoCtx.Provider
        value={{
          objective_score: Number(data.exercise_types.objective_score),
          subjective_score: Number(data.exercise_types.subjective_score),
        }}
      >
        <Content>
          <Row>
            <FGroup {...{ data, filterCfg }} />
          </Row>
          <BetweenBox style={{ padding: "12px 0" }}>
            <FlexBox>
              <SearchBar />
              <Count data={data} style={{ marginLeft: "8px" }} />
            </FlexBox>
            {
              //随机组卷不显示
              !props.is_random && <FlexBox>
                {haveObj(data) && haveSub(data) && (
                    <SFilter
                        filterCfg={filterCfg}
                        maxGrade={data.exercise_types.objective_score}
                    />
                )}
                <div style={{ width: "16px" }} />
                {haveSub(data) && <Action {...{ data, filterCfg }} />}
              </FlexBox>
            }

          </BetweenBox>
          <div style={{ minHeight: "300px" }}>
            <LstHead {...{ data, filterCfg }} />
            {(!isLoaded || data.exercise_users.length == 0) && (
              <AllCenter style={{ minHeight: "300px" }}>
                <Empty image={Empty.PRESENTED_IMAGE_SIMPLE} />
              </AllCenter>
            )}
            {isLoaded &&
              data.exercise_users.map((exercise_user, index) => (
                <LstItem {...{ filterCfg, exercise_user, index, data }} />
              ))}
            <div style={{ padding: "20px 0" }}>
              {data.exercise_types.total_users > 20 && (
                <Pagination
                  current={filterCfg.page}
                  total={data.exercise_types.total_users}
                  pageSize={20}
                  onChange={(p) => {
                    dispatch({
                      type: "page",
                      payload: p,
                    });
                  }}
                />
              )}
            </div>
          </div>
        </Content>
      </InfoCtx.Provider>
    </UpdateCtx.Provider>
  );
};
