import { Link, useParams, useHistory, useLocation } from "react-router-dom";
import { Background, BetweenBox, FlexBox, Paper } from "./util/layout";
import Nav from "./util/widget/Nav";
import React, { useCallback, useMemo, useState } from "react";
import { useLoaded, useMap } from "./util/hooks";
import axios from "axios";
import { IconBtn } from "./util/widget/button";
import { Title } from "./util/widget/typography";
import StatueTag from "./util/widget/StatueTag";
import MenuBar from "./MenuBar";
import { OutlineBtn } from "./util/widget/button";
import { Popover } from "antd";
import Ecerciseallbackagain from "../Ecerciseallbackagain";
import ImmediatelyEnd from "../../poll/pollPublicBtn/ImmediatelyEnd";
import ImmediatelyPublish from "../../poll/pollPublicBtn/ImmediatelyPublish";
import { useRef } from "react";

const pollsStatus = { 1: "未发布", 2: "考试中", 3: "已截止", 4: "已结束" };

const toggleMap = (map, key) => {
  map.set(k, !map.get(key));
};

export default (props) => {
  const ref = useRef(null);
  const coursedata = props.coursedata;
  const { coursesId, Id: exerciseId } = useParams();
  const history = useHistory();
  const location = useLocation();
  const {
    isLoaded: isCommonHeadLoaded,
    data: commonHeadData,
  } = useLoaded(async () => {
    let url = `/exercises/${exerciseId}/common_header.json`;
    return (await axios.get(url)).data;
  }, [exerciseId]);
  const auth = {
    isAssistant: props.isAssistant(),
    isAuthedAssistant: commonHeadData.assistant_auth || false,
    isAdmin: props.isAdmin(),
  };
  const depLst = [
    auth.isAssistant,
    auth.isAuthedAssistant,
    auth.isAdmin,
    commonHeadData,
  ];
  const getsetdata = useCallback(() => {
    let { tab } = this.state;
    try {
      if (tab[0] === "0") {
        this.child.Teacherliststudentlist();
      }
      if (tab[0] === "1") {
        this.child.Teacherliststudentlist();
      }
      if (tab[0] === "2") {
        this.child.Teacherliststudentlist();
      }
      if (tab[0] === "3") {
        this.child.getSettingInfo();
      }
    } catch (e) {}
  },[]);
  const visibleMap = useMap();
  const menuArr = useMemo(() => {
    if ((auth.isAssistant && auth.isAuthedAssistant) || auth.isAdmin) {
      return ["答题列表", "统计结果", "试卷预览", "设置"];
    }
    if (commonHeadData.show_statistic && commonHeadData.exercise_status === 3) {
      return ["答题列表", "统计结果", "设置"];
    }
    return ["答题列表", "设置"];
  }, depLst);
  const btnArr = useMemo(() => {
    let arr = [];
    if (auth.isAdmin) {
      arr.push(
        <Popover title="demo">
          <OutlineBtn>导出</OutlineBtn>
        </Popover>
      );
      if (
        commonHeadData.user_permission.user_commit_counts > 0 &&
        commonHeadData.exercise_status === 2
      ) {
        visibleMap.set("打回重做", false);
        arr.push(
          <OutlineBtn onClick={toggleMap(visibleMap, "打回重做")}>
            打回重做
          </OutlineBtn>
        );
      }
      if (commonHeadData.user_permission.exercise_publish_count > 0) {
        //立即截止
        arr.push(
          <ImmediatelyEnd
            usebyssy
            {...props}
            checkBoxValues={[parseInt(exerciseId)]}
            Exercisetype={"exercise"}
            action={commonHeadData}
          />
        );
      }
      if (commonHeadData.user_permission.exercise_unpublish_count > 0) {
        arr.push(
          <ImmediatelyPublish
            {...props}
            usebyssy
            checkBoxValues={[parseInt(exerciseId)]}
            Exercisetype={"exercise"}
            pushtype={true}
            action={commonHeadData}
            single={true}
            getsetdata={this.getsetdata}
          ></ImmediatelyPublish>
        );
      }
      arr.push(
        <OutlineBtn
          onClick={() => {
            history.push(
              `/classrooms/${coursesId}/exercises/${exerciseId}/edit`
            );
          }}
        >
          编辑试卷
        </OutlineBtn>
      );
      if (auth.isAssistant && !auth.isAuthedAssistant) {
        arr.pop();
      }
    } else {
      if (commonHeadData.user_permission.current_status === 2) {
        arr.push(
          <a
            onClick={() =>
              this.setgameexercise(
                `/classrooms/${coursesId}/exercises/${exerciseId}/users/${props.current_user.login}`
              )
            }
          >
            开始答题
          </a>
        );
      }
      if (
        commonHeadData.exercise_status !== 3 &&
        commonHeadData.exercise_status !== 4
      ) {
        const ansStatus = { 0: "继续答题", 1: "查看答题" };
        arr.push(
          <OutlineBtn
            onClick={() => {
              history.push(
                `/classrooms/${coursesId}/exercises/${exerciseId}/users/${props.current_user.login}`
              );
            }}
          >
            {ansStatus[commonHeadData.user_permission.current_status]}
          </OutlineBtn>
        );
      }
    }
  }, depLst);
  const btnMaper = useCallback(() => {});
  const [currTab, setTab] = useState(menuArr[0]);
  return (
    <Background>
      <Nav
        items={[
          <Link to={`/classrooms/${coursesId}`}>{coursedata.name}</Link>,
          <Link
            to={`/classrooms/${coursesId}/exercises/${commonHeadData.user_permission.left_banner_id}`}
          >
            试卷
          </Link>,
          "试卷详情",
        ]}
      />
      <FlexBox>
        <IconBtn
          type="arrow-left"
          onClick={() =>
            history.push(
              `/classrooms/${coursesId}/exercises/${commonHeadData.user_permission.left_banner_id}`
            )
          }
        />
        <Title>{commonHeadData.exercise_name}</Title>
        <StatueTag type={pollsStatus[commonHeadData.exercise_status]} />
      </FlexBox>
      <Paper>
        <Ecerciseallbackagain
          exerciseId={exerciseId}
          modalname={"打回重做"}
          visible={visibleMap.get("打回重做")}
          callback={toggleMap(visibleMap, "打回重做")}
        />
        <MenuBar
          menuArr={menuArr}
          btnArr={btnMaper(btnArr)}
          value={currTab}
          onChange={setTab}
        />
      </Paper>
    </Background>
  );
};
