import React, {
  isValidElement,
  cloneElement,
  useCallback,
  useContext,
} from "react";
import { Item } from "./style";
import { Typo, Btn } from "../../util/widget";
import { Tooltip } from "antd";
import { useHistory, useParams, useToggle } from "../../util/hooks";
import moment from "moment";
import { cfgFilter, defaultObj } from "./util";
import ModulationModal_exercise from "../../../coursesPublic/ModulationModal_exercise";
import axios from "axios";
import ObjSc from "./ObjScore";
import { InfoCtx } from "../AnswerLst";

const { Text } = Typo;
const { TextBtn } = Btn;

const dataMaper = (page, exercise_user, subjective,index, dObj, sV) => {
  const { userId, coursesId, Id: exerciseId } = useParams();
  const history = useHistory();
  let obj = { ...dObj };
  for (const [k, v] of Object.entries(exercise_user)) {
    if (v !== undefined && v !== null && v !== false) {
      obj[k] = v;
    }
  }
  
  obj.index = (page - 1) * 20 + index + 1;
  switch (exercise_user.commit_status) {
    case 0:
      obj.commit_status = <Text color="#666666">未开始</Text>;
      break;
    case 1:
      obj.commit_status = <Text color="#666666">考试中</Text>;
      break;
    case 2:
      obj.commit_status = <Text color="#2ABD8C">已交卷</Text>;
      break;
    case 3:
      obj.commit_status = <Text color="#FB3226">已交卷(未答)</Text>;
      break;
    default:
      break;
  }
  const reviewBtn = (
    <TextBtn
      onClick={() => {
        history.push(
          `/classrooms/${coursesId}/exercises/${exerciseId}/users/${exercise_user.login}`
        );
      }}
    >
      评阅
    </TextBtn>
  );
  if (exercise_user.review_status) {
    obj.operate = cloneElement(reviewBtn, {
      children: "更改评阅",
    });
    obj.review_status = <Text>已评阅</Text>;
    if (!exercise_user.has_comment && obj.review_status != "-") {
      obj.review_status = <Text>评阅中</Text>;
    }
  } else {
    obj.operate = cloneElement(reviewBtn, { disable: true });
    if (exercise_user.commit_status != 1 && exercise_user.commit_status != 0) {
      obj.review_status = <Text>未评阅</Text>;
    }
    if (exercise_user.commit_status == 2) {
      obj.operate = reviewBtn;
      if (obj.subjective_score ) {
        obj.score = (
          <Text>
            0<span style={{ color: "#FB3226" }}>(待评审)</span>
          </Text>
        );
      } else {
        if(subjective===1){
          obj.subjective_score = (
            <Text>
                 {dObj.exercise_types
              }
              0<span style={{ color: "#FB3226" }}>(待评审)</span>
            </Text>
          );
        }else{
          obj.score = (
            <Text>
              {dObj.exercise_types
              }
              0<span style={{ color: "#FB3226" }}>(待评审)</span>
            </Text>
          );
        }
        
      }
    }
  }
  if (exercise_user.commit_status == 3) {
    obj.operate = cloneElement(obj.operate, {
      onClick: sV, //TODO
    });
  } else if (exercise_user.commit_status == 1) {
    obj.operate = (
      <Tooltip placement="left" title="交卷后才可评阅">
        <Text>评阅</Text>
      </Tooltip>
    );
  }
  if (obj.objective_score != "-") {
    obj.objective_score = (
      <ObjSc exercise_user={exercise_user}>
        <Text>{obj.objective_score}</Text>
      </ObjSc>
    );
  }
  if (obj.user_name != "-" && obj.user_name.length > 5) {
    obj.user_name = (
      <Tooltip title={obj.user_name}>
        <Text>{obj.user_name.slice(0, 5)}...</Text>
      </Tooltip>
    );
  }
  if (obj.user_group_name != "-" && obj.user_group_name.length > 8) {
    obj.user_group_name = (
      <Tooltip title={obj.user_group_name}>
        <Text>
          {obj.user_group_name.slice(0, 4)}...{obj.user_group_name.slice(-4)}
        </Text>
      </Tooltip>
    );
  }
  if (obj.end_at != "-") {
    obj.end_at = moment(obj.end_at).format("YYYY-MM-DD HH:mm");
  }
  for (const key in obj) {
    if (isValidElement(obj[key])) {
      continue;
    }
    obj[key] = <Text>{obj[key]}</Text>;
  }
  return obj;
};

export default ({ filterCfg, exercise_user, index, data }) => {
  const lstCfg = cfgFilter(data);
  const info = useContext(InfoCtx);
  const dObj = defaultObj(lstCfg);
  const [v, sV] = useToggle();
  const _exercise_user = dataMaper(
    filterCfg.page,
    exercise_user,
    data.exercise_types.subjective,
    index,
    dObj,
    sV
  );
  const { Id } = useParams();
  const adjust = useCallback(
    async (v, n) => {
      let url = `/exercises/${Id}/adjust_score.json`;
      await axios.post(url, {
        user_id: exercise_user.user_id,
        subjective_score: v,
        objective_score: n,
      });
      sV();
    },
    [Id]
  );
  return (
    <React.Fragment>
      <Item lstCfg={lstCfg}>{lstCfg.map((c) => _exercise_user[c[1][2]])}</Item>
      {exercise_user.commit_status == 3 && (
        <ModulationModal_exercise
          visible={v}
          Cancel={sV}
          Saves={adjust}
          {...info}
        />
      )}
    </React.Fragment>
  );
};
