import React, { useContext, useState, useCallback } from "react";
import styled from "styled-components";
import { FontMixinGen } from "../../util/cssMixin";
import { Input } from "../../util/widget";
import { UpdateCtx } from "../AnswerLst";
import { FlexBox } from "../../util/layout";
import { Tooltip } from "antd";

const Container = styled(FlexBox)`
  ${FontMixinGen(14)}
  ${Input} {
    width: 54px;
  }
  .deco {
    height: 0px;
    width: 10px;
    border-bottom: 1px solid #d9d9d9;
    margin: 0 6px;
  }
`;

//{min: ,max:}
export default ({ maxGrade }) => {
  const dispatch = useContext(UpdateCtx);
  const [gte, setGte] = useState(undefined);
  const [lte, setLte] = useState(undefined);
  const [tipMin, setMin] = useState(undefined);
  const [tipMax, setMax] = useState(undefined);
  const check = useCallback((gte, lte) => {
    setGte(gte);
    setLte(lte);
    setMin(undefined);
    setMax(undefined);
    if (!gte && !lte) {
      return true;
    }
    const reg = /^[0-9]+.?[0-9]*$/;
    if (reg.test(gte) == false) {
      setMin("请输入正数");
      return false;
    }
    if (reg.test(lte) == false) {
      setMax("请输入正数");
      return false;
    }
    const min = Number(gte);
    const max = Number(lte);
    if (max < min) {
      setMin("最小值不能大于最大值");
      return false;
    }
    if (max > Number(maxGrade)) {
      setMax("分数不能大于当前试卷客观题总分");
      return false;
    }
    return true;
  }, []);
  return (
    <Container>
      按客观题得分分组：
      <Tooltip title={tipMin} visible={Boolean(tipMin)}>
        <Input
          placeholder="最低"
          value={gte}
          onChange={(v) => {
            if (!check(v, lte)) {
              return;
            }
            dispatch({
              type: "objective_score_gte",
              payload: v == "" ? undefined : Number(v),
            });
            dispatch({
              type: "objective_score_lte",
              payload: lte == "" ? undefined : Number(lte),
            });
          }}
          style={{ width: "54px" }}
        />
      </Tooltip>
      <div className="deco" />
      <Tooltip title={tipMax} visible={Boolean(tipMax)}>
        <Input
          placeholder="最高"
          value={lte}
          onChange={(v) => {
            if (!check(gte, v)) {
              return;
            }
            dispatch({
              type: "objective_score_gte",
              payload: gte == "" ? undefined : Number(gte),
            });
            dispatch({
              type: "objective_score_lte",
              payload: v == "" ? undefined : Number(v),
            });
          }}
          style={{ width: "54px" }}
        />
      </Tooltip>
    </Container>
  );
};
