import React, { useState, useCallback } from "react";
import { Row } from "./style";
import { SubQuestionsStatus, ObjQuestionsStatus } from "./quesStatus";
import { isSubQ, isEmpty } from "./util";
import Ques from "./Ques";
import { Hide, Icon } from "../util/widget";
import { Margin } from "../util/layout";
import { useToggle } from "../util/hooks";

export default ({ reviewData }) => {
  let subQs = reviewData.exercise_questions.filter((q) => isSubQ(q));
  let objQs = reviewData.exercise_questions.filter((q) => !isSubQ(q));
  const [v, setV] = useToggle();
  const scrollToAnchor = useCallback((anchorName) => {
    setTimeout(() => {
      if (anchorName) {
        let anchorElement = document.getElementById(anchorName);
        if (anchorElement) {
          anchorElement.scrollIntoView({ block: "start", behavior: "smooth" });
        }
      }
    });
  }, []);
  return (
    <React.Fragment>
      {!isEmpty(objQs) && (
        <Row>
          <ObjQuestionsStatus
            questions={objQs}
            exercise_status={reviewData.exercise.exercise_status}
            scrollToAnchor={(name) => {
              if (!v) {
                setV();
              }
              scrollToAnchor(name);
            }}
          />
          <Hide
            visible={v}
            setVis={setV}
            style={{ textAlign: "left" }}
            hintGen={(b) =>
              b ? (
                <React.Fragment>
                  收起答案详情&nbsp;
                  <Icon
                    style={{
                      display: "inline-block",
                      transform: "rotate(180deg)",
                      transformOrigin: "50% 45%",
                    }}
                  >
                    &#xe76f;
                  </Icon>
                </React.Fragment>
              ) : (
                <React.Fragment>
                  展开查看答题详情&nbsp;
                  <Icon>&#xe76f;</Icon>
                </React.Fragment>
              )
            }
          >
            <div style={{ height: "10px" }} />
            {objQs.map((q) => (
              <Ques
                question={q}
                is_md={reviewData.exercise.is_md}
                exercise_answer_user={reviewData.exercise_answer_user}
                exercise={reviewData.exercise}
              />
            ))}
          </Hide>
        </Row>
      )}
      {!isEmpty(subQs) && (
        <Row>
          <SubQuestionsStatus
            questions={subQs}
            exercise_status={reviewData.exercise.exercise_status}
            scrollToAnchor={scrollToAnchor}
          />
          {subQs.map((q) => (
            <Ques
              question={q}
              is_md={reviewData.exercise.is_md}
              exercise_answer_user={reviewData.exercise_answer_user}
              exercise={reviewData.exercise}
            />
          ))}
        </Row>
      )}
    </React.Fragment>
  );
};
