import React, { useCallback, useEffect, useLayoutEffect } from "react";
import { Row, ScoreDesc, QtypeScoreDesc, StuDesc, Row2 } from "./style";
import axios from "axios";
import { notification, Tooltip } from "antd";
import { BetweenBox, FlexBox, Margin } from "../util/layout";
import { useParams, useToggle, useHistory } from "../util/hooks";
import { Btn, Popover, Modal, Icon } from "../util/widget";
import moment from "moment";

const { OutlineBtn } = Btn;
const { NormalModal } = Modal;

const cfg = [
  ["单选题", "q_singles"],
  ["多选题", "q_doubles"],
  ["判断题", "q_judges"],
  ["填空题", "q_nulls"],
  ["简答题", "q_mains"],
  ["实训题", "q_shixuns"],
  ["编程题", "q_pros"],
];

export default ({ reviewData }) => {
  const [visible, setV] = useToggle();
  const userId = reviewData.exercise_answer_user.user_id;
  const { coursesId, Id: exerciseId } = useParams();
  const history = useHistory();

  const repeatExercise = useCallback(
    async (userId, exerciseId) => {
      try {
        const resp = await axios.post(
          `/exercises/${exerciseId}/redo_exercise.json`,
          {
            user_ids: [userId],
          }
        );
        notification.open({
          message: "提示",
          description: `${resp.data.message}`,
        });
        if(reviewData.exercise.is_random){
          history.push(
            `/classrooms/${coursesId}/exercises/${exerciseId}/student_exercise_random_detail?tab=0`
          );
        }else{
          history.push(
            `/classrooms/${coursesId}/exercises/${exerciseId}/student_exercise_list?tab=0`
          );
        }
      } catch (e) {
        console.error(e);
      }
    },
    [coursesId, exerciseId]
  );
  const canRepeat = reviewData.exercise.exercise_status !== 3;
  if (!reviewData) {
    return null;
  }
  return (
    <React.Fragment>
      <NormalModal
        visible={visible}
        onOk={() => {
          repeatExercise(userId, exerciseId);
          setV();
        }}
        onCancel={setV}
        title="提示"
      >
        学生将得到一次重新答题的机会，现有的答题情况将被清空
        <br />
        是否确认回退TA的试卷答题
      </NormalModal>
      <Row>
        <BetweenBox style={{ color: "black" }}>
          <ScoreDesc>
            考试时长：
            {reviewData.exercise.time != -1
              ? `${reviewData.exercise.time} 分钟`
              : "未限时"}
            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 合计：
            {reviewData.exercise_scores.exercise_types.q_counts}
            &nbsp;题&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 满分：
            {reviewData.exercise_scores.exercise_types.q_scores}&nbsp;分
          </ScoreDesc>
          {canRepeat ? (
            <OutlineBtn onClick={setV}>
              <Icon>&#xe762;</Icon>&nbsp;打回重做
            </OutlineBtn>
          ) : (
            <Tooltip
              title={
                <React.Fragment>
                  <div>截止时间已到，无法打回重做</div>
                  <div>请修改截止时间后再操作</div>
                </React.Fragment>
              }
            >
              <OutlineBtn disable={true}>
                <Icon>&#xe762;</Icon>&nbsp;打回重做
              </OutlineBtn>
            </Tooltip>
          )}
        </BetweenBox>
      </Row>
      <Row2>
        <BetweenBox style={{ width: "100%" }}>
          <FlexBox>
            <StuDesc>
              学生姓名
              <span>{reviewData.exercise_answer_user.user_name}</span>
            </StuDesc>
            <StuDesc>
              开始答题
              <span>
                {reviewData.exercise_answer_user.start_at &&
                  moment(reviewData.exercise_answer_user.start_at).format(
                    "YYYY-MM-DD HH:mm"
                  )}
              </span>
            </StuDesc>
            <StuDesc>
              提交试卷
              <span>
                {reviewData.exercise_answer_user.end_at &&
                  moment(reviewData.exercise_answer_user.end_at).format(
                    "YYYY-MM-DD HH:mm"
                  )}
              </span>
            </StuDesc>
          </FlexBox>
          <FlexBox style={{ flexDirection: "column" }}>
            <Margin h="6px" />
            <ScoreDesc style={{ marginLeft: "auto" }}>
              总分&nbsp;
              <span style={{ color: "#FB3226" }}>
                {reviewData.exercise_questions
                  .map((q) => Number(q.user_score))
                  .reduce((acc, cur) => acc + cur, 0)
                  .toFixed(1)}
              </span>
              &nbsp; 分
            </ScoreDesc>
          </FlexBox>
        </BetweenBox>
      </Row2>
    </React.Fragment>
  );
};

/* <FlexBox>
  {cfg.map(([str, props]) => {
    if (reviewData.exercise_scores.exercise_types[props] > 0) {
      return (
        <QtypeScoreDesc key={str}>
          {str} {reviewData.exercise_scores.exercise_types[props]} 题/共{" "}
          {reviewData.exercise_scores.exercise_types[`${props}_scores`]} 分
        </QtypeScoreDesc>
      );
    }
  })}
</FlexBox>; */
