import React, { useReducer,useState } from "react";
import axios from "axios";
import { Background, Paper } from "../util/layout";
import { useParams, useLoaded, useLocation, HooksMocker,useHistory } from "../util/hooks";
import Content from "./Content";
import Head from "./Head";
import update from "immutability-helper";
import Nav from "./CommonNav";
import { UpdateCtx } from "./SinglePage";

import NextStu from "./NextStu";
import { Spin } from "antd";

const Inner = ({ current_user }) => {
  let { idx, Id: exerciseId,coursesId } = useParams();
  const history = useHistory();

  idx = Number(idx);
  const users = useLocation().state;
  const [reviewData, dispatch] = useReducer((state, action) => {
    switch (action.type) {
      case "init":
        return action.payload;
      case "update":
        return update(state, {
          exercise_questions: {
            [action.payload.q_position - 1]: { $set: action.payload },
          },
        });
      default:
        return;
    }
  });
  const { isLoaded } = useLoaded(async () => {
    if(!users){
      history.push(`/classrooms/${coursesId}/exercises/${exerciseId}/student_exercise_list?tab=0`)
      return
    }
    if (exerciseId) {
      const payload = (
        await axios.get(`/exercises/${exerciseId}/review_exercise.json`, {
          params: {
            login: users.map((u) => u.user_login)[idx],
          },
        })
      ).data;
      dispatch({ type: "init", payload });
      return true;
    }
  }, [exerciseId]);

  if (!isLoaded) {
    return <Spin spinning={true} size="large" style={{width:'100%',height:'80%',position:'fixed',display:'flex',alignItems:'center',textAlign:'center',justifyContent:'center'}}></Spin>;
  }
  return (
    <Background>
      <Nav {...{ current_user, reviewData }} />
      <Paper>
        <UpdateCtx.Provider value={dispatch}>
          <Head reviewData={reviewData} />
          <Content reviewData={reviewData} />
        </UpdateCtx.Provider>
        <NextStu users={users} idx={idx} />
      </Paper>
    </Background>
  );
};

export default (props) => {
  return (
    <HooksMocker {...props}>
      <Inner current_user={props.current_user}  />
    </HooksMocker>
  );
};
