import React, { useReducer, createContext } from "react";
import axios from "axios";
import { Background, Paper } from "../util/layout";
import { useParams, useLoaded } from "../util/hooks";
import Content from "./Content";
import Head from "./Head";
import update from "immutability-helper";
import Nav from "./CommonNav";
import { Spin } from "antd";


export const UpdateCtx = createContext(null);

export default ({ current_user }) => {
  const { userId, Id: exerciseId } = useParams();
  const [reviewData, dispatch] = useReducer((state, action) => {
    switch (action.type) {
      case "init":
        return action.data;
      case "update":
        const idx = state.exercise_questions.findIndex(
          (q) => q.q_position === action.payload.q_position
        );
        return update(state, {
          exercise_questions: {
            [idx]: { $set: action.payload },
          },
        });
      default:
        return state;
    }
  });
  const { isLoaded } = useLoaded(async () => {
    if (exerciseId) {
      const data = (
        await axios.get(`/exercises/${exerciseId}/review_exercise.json`, {
          params: {
            login: userId,
          },
        })
      ).data;
      dispatch({ type: "init", data });
      return true;
    }
  }, [exerciseId]);
  if (!isLoaded) {
    return <Spin spinning={true} size="large" style={{width:'100%',height:'80%',position:'fixed',display:'flex',alignItems:'center',textAlign:'center',justifyContent:'center'}}></Spin>;

  }
  return (
    <Background>
      <Nav {...{ current_user, reviewData }} />
      <Paper>
        <UpdateCtx.Provider value={dispatch}>
          <Head reviewData={reviewData} />
          <Content reviewData={reviewData} />
        </UpdateCtx.Provider>
      </Paper>
    </Background>
  );
};
