import React from "react";
import { FlexBox, BetweenBox } from "../util/layout";
import { CircleBtn } from "../util/widget/button";
import { Show, QType, ScoreDesc } from "./style";
import _ from "lodash";

const btnGroupGen = (classnameMapper) => ({ questions, scrollToAnchor }) => (
  <FlexBox style={{ flexWrap: "wrap" }}>
    {_.chunk(questions, 5).map((itemof5) => {
      return (
        <FlexBox style={{ margin: "8px 0" }}>
          {itemof5.map((item) => (
            <CircleBtn
              style={{ marginRight: "8px" }}
              onClick={() => {
                scrollToAnchor(`question_${item.q_position}`);
              }}
              key={item.q_position}
              className={classnameMapper(item)}
            >
              {item.q_position}
            </CircleBtn>
          ))}
          <div style={{ width: "24px" }} />
        </FlexBox>
      );
    })}
  </FlexBox>
);

const quesStatusGen = (cfg) => {
  let Widget = btnGroupGen(cfg.classnameMapper);
  return ({ exercise_status, questions, scrollToAnchor }) => {
    return (
      <React.Fragment>
        <BetweenBox>
          <FlexBox>
            <QType>{cfg.type}</QType>
            {cfg.class.map(([color, str]) => (
              <Show color={color} key={str}>
                {str}
              </Show>
            ))}
          </FlexBox>
          <ScoreDesc>
            总分&nbsp;
            <span>
              {questions
                .map((q) => Number(q.question_score))
                .reduce((acc, cur) => acc + cur, 0)}
            </span>
            &nbsp; 分
          </ScoreDesc>
        </BetweenBox>
        <Widget questions={questions} scrollToAnchor={scrollToAnchor} />
      </React.Fragment>
    );
  };
};
const subCfg = {
  type: "主观题",
  class: [
    ["#1DBF61", "已评"],
    ["#FB3226", "未评"],
  ],
  classnameMapper: (item) => {
    if (
      (item.answer_status === 1 && item.user_score === null) ||
      item.answer_status === 0
    ) {
      return "red";
    }
    return "green";
  },
};
const objCfg = {
  type: "客观题",
  class: [
    ["#1DBF61", "正确"],
    ["#FB3226", "错误"],
    ["#FD8001", "部分得分"],
  ],
  classnameMapper: (item) =>
    item.answer_status == 1
      ? "green"
      : item.answer_status == 2
      ? "yellow"
      : "red",
};
const gSubCfg = {
  type: "主观题",
  class: [
    ["#1DBF61", "已评"],
    ["#FB3226", "未评"],
  ],
  classnameMapper: (item) => (item.reviewed ? "green" : "red"),
};

export const SubQuestionsStatus = quesStatusGen(subCfg);
export const GSubQuestionsStatus = quesStatusGen(gSubCfg);
export const ObjQuestionsStatus = quesStatusGen(objCfg);
