import React, {
  useState,
  useContext,
  useCallback,
  isValidElement,
} from "react";
import moment from "moment";
import axios from "axios";
import { Input, Popover, Table, Typo } from "../../../util/widget";
import { notification, Tooltip } from "antd";
import classnames from "classnames";
import { UpdateCtx as SCtx } from "../../SinglePage";
import update from "immutability-helper";
import { TextBtn } from "../../../util/widget/button";

const { Head, Item } = Table;
const { Text } = Typo;

const AdjustInput = ({ item, question, user_id }) => {
  const [score, _setS] = useState(
    item.user_score == "0.0" ? undefined : item.user_score
  );
  const [tip, setTip] = useState("");
  const dispatch = useContext(SCtx);
  const setS = useCallback((v) => {
    _setS(v);
    setTip("");
    if (v == "") {
      return;
    }
    const reg = /^[0-9]+.?[0-9]*$/;
    if (reg.test(v) == false) {
      setTip("请输入正数");
      return;
    }
    const num = Number(v);
    if (num > Number(item.game_score)) {
      setTip("分数不能大于当前题目的分数");
      return;
    }
  }, []);
  const adjustScore = useCallback(
    async (v) => {
      let url = `/exercise_questions/${question.question_id}/adjust_score.json`;
      await axios.post(url, {
        score: Number(v),
        user_id,
        shixun_challenge_id: item.shixun_challenge_id,
      });
      let idx = question.shixun_details.findIndex(
        (d) => d.shixun_challenge_id == item.shixun_challenge_id
      );
      question = update(question, {
        user_score: {
          $set:
            Number(question.user_score) +
            Number(v) -
            Number(question.shixun_details[idx].stage_list[0].user_score),
        },
        shixun_details: {
          [idx]: {
            stage_list: { [0]: { user_score: { $set: Number(v).toFixed(1) } } },
          },
        },
        answer_status: { $set: 1 },
      });
      dispatch({
        type: "update",
        payload: question,
      });
      notification.open({
        message: "成功",
        description: "已修改当前评分",
      });
    },
    [question, item.shixun_challenge_id, user_id]
  );
  return (
    <Tooltip placement="top" title={tip} visible={Boolean(tip)}>
      <Input
        style={{ width: "100px" }}
        placeholder="0.0"
        value={score}
        onChange={setS}
        onBlur={() => {
          if (tip || !score) {
            return;
          }
          adjustScore(score);
        }}
        className={classnames({ "has-error": Boolean(tip) })}
      />
    </Tooltip>
  );
};

const cfg = [
  ["关卡", 2, "position"],
  ["任务名称", 5, "name"],
  ["评测次数", 2, "evaluate_count"],
  ["完成时间", 5, "finished_time"],
  ["耗时", 5, "time_consuming"],
  ["查看答案", 3, (i) => (i.view_answer ? "已查看" : "未查看")],
  [
    "经验值",
    3,
    (i) => (
      <div>
        <span style={{ color: "#29bda9" }}>{i.myself_experience}</span>/
        {i.experience}
      </div>
    ),
  ],
  [
    "得分/满分",
    3,
    (i) => (
      <div>
        <span style={{ color: "#ff954c" }}>{i.user_score}</span>/{i.game_score}
      </div>
    ),
  ],
  [
    "调分",
    3,
    (i, question, user_id) => (
      <AdjustInput item={i} {...{ question, user_id }} />
    ),
  ],
  [
    undefined,
    3,
    (i, question, _, jump) =>
      Boolean(question.shixun_details[i.position - 1].shixun_detail) ? (
        <TextBtn
          onClick={() => jump(`question_${question.q_position}_${i.position}`)}
        >
          查看
        </TextBtn>
      ) : (
        <div>-</div>
      ),
  ],
];

export default ({ question, exercise_answer_user }) => {
  const jump = useCallback((anchorName) => {
    setTimeout(() => {
      if (anchorName) {
        let anchorElement = document.getElementById(anchorName);
        if (anchorElement) {
          anchorElement.scrollIntoView({ block: "start", behavior: "smooth" });
        }
      }
    });
  }, []);
  return (
    <React.Fragment>
      <Head lstCfg={cfg}>
        {cfg.map((c) => (
          <div key={c[0]}>{c[0]}</div>
        ))}
      </Head>
      {question.shixun_details
        .map((d) => ({
          ...d.stage_list[0],
          shixun_challenge_id: d.shixun_challenge_id,
        }))
        .map((i) => (
          <Item lstCfg={cfg}>
            {cfg.map((c) => {
              let widget;
              if (typeof c[2] == "string") {
                widget = i[c[2]];
              } else {
                widget = c[2](i, question, exercise_answer_user.user_id, jump);
              }
              if (!isValidElement(widget)) {
                widget = <Text>{widget}</Text>;
              }
              return widget;
            })}
          </Item>
        ))}
    </React.Fragment>
  );
};
