import React from "react";
import { BetweenBox, FlexBox, Margin } from "../../../util/layout";
import { Table, Typo } from "../../../util/widget";
import { codeMirrorCfg } from "../util";
import { UnControlled as CodeMirror } from "react-codemirror2";
import styled from "styled-components";
import { Base64 } from "js-base64";

const Code = styled.div`
  & .CodeMirror {
    height: auto !important;
  }
  border: 1px solid #e2e2e2;
`;
const CodeH = styled(BetweenBox)`
  border: 1px solid #e2e2e2;
  border-bottom: 0px;
  height: 30px;
`;

const { Head, Item } = Table;
const { Text } = Typo;

const cfg = [
  ["评测次数", 2, "position"],
  ["详细信息", 8, "output_detail"],
];
const execDefau = [
  {
    position: "--",
    output_detail: "--",
  },
];

export default ({ item, q_position }) => {
  if (item.outputs.length == 0) {
    item.outputs = execDefau;
  }
  return (
    <React.Fragment>
      <FlexBox
        id={`question_${q_position}_${item.position}`}
        style={{ margin: "20px 0" }}
      >
        <div className="panel-inner-icon backgroud4CACFF">
          <i className="fa fa-code font-16 color_white" />
        </div>
        <Margin w="3px" />
        <div className="font-16 font-bd">第{item.position}关</div>
        <Margin w="5px" />
        <a
          target="_blank"
          href={`/tasks/${item.game_identifier}`}
          style={{ cursor: "pointer" }}
        >
          <div className="font-16">{item.name}</div>
        </a>
      </FlexBox>
      <Head lstCfg={cfg}>
        {cfg.map((c) => (
          <div>{c[0]}</div>
        ))}
      </Head>
      {item.outputs.map((o) => (
        <Item lstCfg={cfg}>
          {cfg.map((c) => (
            <Text>{o[c[2]]}</Text>
          ))}
        </Item>
      ))}
      <Margin h="12px" />
      <CodeH>
        <div>最近通过的代码</div>
        <div style={{ textAlign: "right" }}>{item.path}</div>
      </CodeH>
      <Code>
        <CodeMirror value={item.passed_code} options={codeMirrorCfg} />
      </Code>
    </React.Fragment>
  );
};

const progDefau = [
  {
    index:'--',
    error_msg: Base64.encode("--"),
  },
];

export const ProgDetail = ({ evaluate_codes, user_answer }) => {
  if (!evaluate_codes || evaluate_codes.length == 0) {
    evaluate_codes = progDefau;
  }
  return (
    <React.Fragment>
      <Head lstCfg={cfg}>
        {cfg.map((c) => (
          <div>{c[0]}</div>
        ))}
      </Head>
      {evaluate_codes.map((i, idx) => (
        <Item lstCfg={cfg} style={{borderLeft:'1px solid #f4f4f4',borderRight:'1px solid #f4f4f4'}}>
          <Text style={{borderRight:'1px solid #f4f4f4',height:'54px'}}>{i.index==='--'?i.index:idx + 1}</Text>
          <Text>{Base64.decode(i.error_msg)}</Text>
        </Item>
      ))}
      <Margin h="12px" />
      <CodeH>
        <div>最近通过的代码</div>
      </CodeH>
      <Code>
        <CodeMirror
          value={user_answer && Base64.decode(user_answer)}
          options={codeMirrorCfg}
        />
      </Code>
    </React.Fragment>
  );
};
