import React, {
  useState,
  useContext,
  useCallback,
  isValidElement,
} from "react";
import moment from "moment";
import axios from "axios";
import { Input, Popover, Table, Typo } from "../../../util/widget";
import { notification } from "antd";
import classnames from "classnames";
import { UpdateCtx as GCtx } from "../../GroupPage";
import { useLocation } from "../../../util/hooks";
import update from "immutability-helper";

const { Head, Item } = Table;
const { Text } = Typo;

const AdjustInput = ({ item, question }) => {
  const [score, _setS] = useState();
  const [tip, setTip] = useState("");
  const dispatch = useContext(GCtx);
  const user_ids = useLocation().state;
  const setS = useCallback((v) => {
    _setS(v);
    setTip("");
    if (v == "") {
      return;
    }
    const reg = /^[0-9]+.?[0-9]*$/;
    if (reg.test(v) == false) {
      setTip("请输入正数");
      return;
    }
    const num = Number(v);
    if (num > Number(item.game_score)) {
      setTip("分数不能大于当前题目的分数");
      return;
    }
  }, []);
  const adjustScore = useCallback(async (v) => {
    await axios.post(
      `/exercise_questions/${question.question_id}/batch_adjust_score.json`,
      {
        min_score: Number(v),
        max_score: Number(v),
        user_ids,
        shixun_challenge_id: item.shixun_challenge_id,
      }
    );
    question = update(question, { reviewed: { $set: true } });
    question = update(question, { partial_reviewed: { $set: false } });
    dispatch({
      type: "update",
      payload: question,
    });
    notification.open({
      message: "成功",
      description: "已修改当前评分",
    });
  }, [question.question_id, item.shixun_challenge_id]);
  return (
    <Popover placement="top" content={tip} visible={Boolean(tip)}>
      <Input
        placeholder="0.0"
        value={score}
        onChange={setS}
        onBlur={tip && score ? undefined : ()=>adjustScore(score)}
        className={classnames({ "has-error": Boolean(tip) })}
      />
    </Popover>
  );
};

const cfg = [
  ["关卡", 2, "position"],
  ["任务名称", 5, "name"],
  ["调分", 3, (i, question) => <AdjustInput item={i} question={question} />],
];

export default ({ question }) => {
  return (
    <React.Fragment>
      <Head lstCfg={cfg}>
        {cfg.map((c) => (
          <div key={c[0]}>{c[0]}</div>
        ))}
      </Head>
      {question.shixun_details
        .map((d) => ({
          ...d.stage_list[0],
          shixun_challenge_id: d.shixun_challenge_id,
        }))
        .map((i) => (
          <Item lstCfg={cfg}>
            {cfg.map((c) => {
              let widget;
              if (typeof c[2] == "string") {
                widget = i[c[2]];
              } else {
                widget = c[2](i, question);
              }
              if (!isValidElement(widget)) {
                widget = <Text>{widget}</Text>;
              }
              return widget;
            })}
          </Item>
        ))}
    </React.Fragment>
  );
};
