import React, { useState, useCallback } from "react";
import { FlexBox, Margin } from "../../../../util/layout";
import { Input, Popover, Btn, Modal } from "../../../../util/widget";
import classnames from "classnames";
import { useToggle } from "../../../../util/hooks";

const { NormalModal } = Modal;
const { TextBtn, PrimaryBtn } = Btn;

export default ({ question, inputVisible, adjustScore, setVis }) => {
  const [v, setV] = useState({ max: undefined, min: undefined });
  const [tipMin, setTipMin] = useState(undefined);
  const [tipMax, setTipMax] = useState(undefined);
  const [modalV, setMV] = useToggle();
  const check = useCallback((v) => {
    setTipMax(undefined);
    setTipMin(undefined);
    const reg = /^[0-9]+.?[0-9]*$/;
    if (reg.test(v.max) == false) {
      setTipMax("请输入正数");
      return;
    }
    if (reg.test(v.min) == false) {
      setTipMin("请输入正数");
      return;
    }
    if (Number(v.min) > Number(v.max)) {
      setTipMin("最小分数不能大于最大分数");
      return;
    }
    if (Number(v.max) > Number(question.question_score)) {
      setTipMax("分数不能大于当前题目的分数");
      return;
    }
  }, []);

  return (
    <FlexBox>
      <NormalModal
        visible={modalV}
        onClose={setMV}
        onOk={() => {
          adjustScore(v, true);
          setMV();
        }}
        onCancel={() => {
          adjustScore(v, false);
          setMV();
        }}
        title="提示"
      >
        部分学生本题已评阅，是否以本次评阅为准？
        <br />
        （选“是”将覆盖原始评阅）
      </NormalModal>
      {!inputVisible && <TextBtn onClick={setVis}>调分</TextBtn>}
      {inputVisible && (
        <FlexBox>
          在以下区间中为学生随机赋分：
          <Popover placement="top" visible={Boolean(tipMin)} content={tipMin}>
            <Input
              style={{ width: "50px", height: "24px" }}
              placeholder="最低"
              value={v.min}
              onChange={(c) => {
                const newV = { ...v, min: c };
                setV(newV);
                check(newV);
              }}
              className={classnames({ "has-error": Boolean(tipMin) })}
            />
          </Popover>
          <div
            style={{
              width: "10px",
              height: "0px",
              borderBottom: "1px solid #999999",
              margin: "0 4px",
            }}
          />
          <Popover placement="top" visible={Boolean(tipMax)} content={tipMax}>
            <Input
              style={{ width: "50px", height: "24px" }}
              placeholder="最高"
              value={v.max}
              onChange={(c) => {
                const newV = { ...v, max: c };
                setV(newV);
                check(newV);
              }}
              className={classnames({ "has-error": Boolean(tipMax) })}
            />
          </Popover>
          <Margin w="5px" />
          分
          <Margin w="5px" />
          <PrimaryBtn
            disable={tipMax || tipMin || !v.max || !v.min}
            onClick={() => {
              if (question.partial_reviewed) {
                setMV();
              } else {
                adjustScore(v, true);
              }
            }}
          >
            确认
          </PrimaryBtn>
        </FlexBox>
      )}
      <Margin w="5px" />
    </FlexBox>
  );
};
