import SAdjust from "./Adjust";
import GAdjust from "./GroupAdjust";
import { useToggle, useLocation, useProps } from "../../../../util/hooks";
import axios from "axios";
import update from "immutability-helper";
import { useCallback, useState, useContext } from "react";
import { UpdateCtx as GCtx,updateloading} from "../../../GroupPage";
import { UpdateCtx as SCtx } from "../../../SinglePage";
import { notification } from "antd";

const updateComm = (
  question,
  comment,
  user_name = "default",
  user_picture = "avatar"
) => {
  question = update(question, {
    question_comments: {
      $set: {
        comment: comment,
        updated_at: Date(),
        user_name,
        user_picture,
      },
    },
  });
  return question;
};

const singleUpdate = (
  question,
  comment,
  user_score,
  user_name = "default",
  user_picture = "avatar"
) => {
  question = update(question, {
    answer_status: { $set: 1 },
    user_score: { $set: Number(user_score) },
  });
  if (comment !== undefined) {
    question = updateComm(question, comment, user_name, user_picture);
  }
  return question;
};
const groupUpdate = (
  question,
  comment,
  user_name = "default",
  user_picture = "avatar"
) => {
  question = update(question, {
    reviewed: { $set: true },
    partial_reviewed: { $set: false },
  });
  if (comment !== undefined) {
    question = question = updateComm(
      question,
      comment,
      user_name,
      user_picture
    );
  }
  return question;
};

const useGAdjust = (question) => {
  const [vis, setV] = useToggle();
  const props = useProps();
  const [user_name, user_picture] = [
    props.user && props.user.username,
    props.user && props.user.image_url,
  ];
  const user_ids =window.sessionStorage.getItem('userid').split(',');
  const [comm, setComm] = useState(undefined);
  const dispatch = useContext(GCtx);
  const adjustScore = useCallback(
    async (v, cover_all) => {
      
      dispatch({
        type: "isloading",
      });
       axios.post(
        `/exercise_questions/${question.question_id}/batch_adjust_score.json`,
        {
          min_score: Number(v.min),
          max_score: Number(v.max),
          user_ids,
          comment: comm,
          cover_all: cover_all,
        }
      ).then((result)=>{
        if(result){
          setV();
          notification.open({
            message: "成功",
            description: "成功批量调分",
          });
          setComm(undefined);
        }
      });
      dispatch({
        type: "update",
        payload: groupUpdate(question, comm, user_name, user_picture),
      });
      
    
    },
    [question.question_id, user_ids, comm, user_name, user_picture]
  );
  return { vis, setV, comm, setComm, adjustScore };
};

const useAdjust = (question, exercise_answer_user) => {
  const [vis, setV] = useToggle();
  const [comm, setComm] = useState(undefined);
  const props = useProps();
  const [user_name, user_picture] = [
    props.user && props.user.username,
    props.user && props.user.image_url,
  ];
  const dispatch = useContext(SCtx);
  var adjustScore = useCallback(
    async (v) => {
      await axios.post(
        `/exercise_questions/${question.question_id}/adjust_score.json`,
        {
          score: Number(v),
          user_id: exercise_answer_user.user_id,
          comment: comm,
        }
      );
      dispatch({
        type: "update",
        payload: singleUpdate(question, comm, v, user_name, user_picture),
      });
      setV();
      setComm(undefined);
    },
    [
      question.question_id,
      comm,
      exercise_answer_user.user_id,
      user_name,
      user_picture,
    ]
  );
  return { vis, setV, comm, setComm, adjustScore };
};

export { SAdjust, GAdjust, useGAdjust, useAdjust };
