import React, { Component } from "react";

import { InputNumber, Radio } from 'antd';
import CustomEditor from "../../../../common/components/custom-editor"
import axios from 'axios'
import { qNameArray } from './common'
import { ActionBtn, validateLength } from 'educoder';
const RadioGroup = Radio.Group;


class SingleEditor extends Component {
  constructor(props) {
    super(props);
    /**
      choice_id: 32076
      choice_position: 1
      choice_text: "1"
      standard_boolean: true
     */
    const { question_choices } = this.props;
    let _standard_answers = undefined;
    let _question_choices = undefined;
    if (question_choices) {
      _standard_answers = []
      _question_choices = []

      question_choices.forEach((item, index) => {
        _standard_answers.push(item.standard_boolean)
        _question_choices.push(item.choice_text)
      })
    }
    this.state = {
      question_choices: _question_choices || ['对', '错'],
      standard_answers: _standard_answers || [false, true],
      question_title: this.props.question_title || '',
      question_type: this.props.question_type || 2,
      question_score: this.props.question_score || this.props.init_question_score,
      question_title_error: false
    }
  }

  onSave = () => {
    const { question_title, question_score, question_choices, standard_answers } = this.state;
    const { question_id_to_insert_after, question_id } = this.props
    // TODO check
    const answerArray = standard_answers.map((item, index) => { return item == true ? index + 1 : -1 }).filter(item => item != -1);
    if (!question_title || !validateLength(question_title, 10000)) {
      this.setState({
        question_title_error: true
      })
      this.props.showNotification(!question_title ? '题目：不能为空' : '题目不能超10000字符！');
      return;
    }
    const intScore = parseFloat(question_score)
    if (intScore == 0) {
      this.props.showNotification('分值：必须大于0'); return;
    } else if (!question_score || intScore == NaN) {
      this.props.showNotification('分值：不能为空'); return;
    }
    if (!answerArray || answerArray.length == 0) {
      this.props.showNotification('必须设置标准答案'); return;
    }
    /**
        {
    "question_title":"现在在下雨",
    "question_type":2,
    "question_score":5,
    "question_choices":["正确","错误"],
    "standard_answers":[1]    
}
    }*/
    const Id = this.props.match.params.Id
    if (question_id) {
      const editUrl = this.props.getEditQuestionUrl(question_id);
      axios.put(editUrl, {
        question_title,
        question_type: 2,
        question_score,
        question_choices,
        standard_answers: answerArray,
        insert_id: question_id_to_insert_after || undefined
      }).then((response) => {
        if (response.data.status == 0) {
          this.props.addSuccess()
        } else if (response.data.status == 3) {
          // 已发布试卷编辑保存
          this.props.changeScore(question_id, answerArray);
        }
      })
        .catch(function (error) {
          console.log(error);
        });
    } else {
      const url = this.props.getAddQuestionUrl();

      axios.post(url, {
        exercise_bank_id: Id,
        question_title,
        question_type: 2,
        question_score,
        question_choices,
        standard_answers: answerArray,
        insert_id: question_id_to_insert_after || undefined
      })
        .then((response) => {
          if (response.data.status == 0) {
            this.props.addSuccess()
          }
        })
        .catch(function (error) {
          console.log(error);
        });
    }
  }
  onCancel = () => {
    this.props.onEditorCancel()
  }
  componentDidMount = () => {

  }
  onOptionClick = (e) => {
    const value = e.target.value;
    if (value) {
      this.setState({ standard_answers: [true, false] })
    } else {
      this.setState({ standard_answers: [false, true] })
    }
  }
  on_question_score_change = (e) => {
    this.setState({ question_score: e })
  }

  onSetQuestionTitle = (value) => {
    this.setState({
      question_title: value,
      question_title_error: false
    })
  }

  render() {
    let { question_title, question_score, question_type, standard_answers, question_title_error } = this.state;
    let { index, exerciseIsPublish, is_md } = this.props;

    const qNumber = `question_${index}`;

    return (
      <div className="padding20-30 bor-bottom-greyE" id={qNumber}>
        <style>{`
              .optionMdEditor {
                flex: 0 0 800px
              }
              .optionRow {
                margin: 2px;
              }
            `}</style>
        <p className="mb10 clearfix">
          <span className="color-blue font-16 mr20 fl">{qNameArray[question_type]}</span>
          <span className="color-grey-9 font-12 fl">（客观题，由系统自动评分，请设置标准答案）</span>
        </p>

        <CustomEditor is_md={is_md} height={is_md ? 155 : 109}
          placeholder="请您输入题目"
          value={question_title}
          isShowEditor={true}
          isError={question_title_error}
          autoFocus={true}
          onChange={this.onSetQuestionTitle}
        />

        <div>
          <RadioGroup onChange={this.onOptionClick} value={standard_answers[0]}>
            <Radio value={true} >正确</Radio>
            <Radio value={false} >错误</Radio>
          </RadioGroup>
          {!exerciseIsPublish && <span style={{ color: '#FF6800' }}>温馨提示：点击选项，可以直接设置标准答案</span>}

        </div>

        <div>
          分值：
              <InputNumber step={0.1} precision={1} min={0} max={100} style={{ width: 100 }} value={question_score} onChange={this.on_question_score_change}
            disabled={exerciseIsPublish}
          ></InputNumber> 分

              <span className="fr">
            <ActionBtn style="greyBack" className="middle mr20" onClick={this.onCancel}
            >取消</ActionBtn>
            <ActionBtn style="blue" className="middle" onClick={this.onSave}>保存</ActionBtn>
          </span>

        </div>

      </div>
    )
  }
}
export default SingleEditor