import React, { Component } from "react"

import { InputNumber } from 'antd'
import CustomEditor from "../../../../common/components/custom-editor"
import axios from 'axios'
import { qNameArray } from './common'

import { ActionBtn, validateLength } from 'educoder'

class MainEditor extends Component {
  constructor(props) {
    super(props);
    /**
      choice_id: 32076
      choice_position: 1
      choice_text: "1"
      standard_boolean: true
     */
    const { standard_answer } = this.props;
    let _standard_answers = undefined;
    if (standard_answer) {
      _standard_answers = standard_answer

    }
    this.state = {
      standard_answers: _standard_answers || [''],
      question_title: this.props.question_title || '',
      question_type: this.props.question_type || 2,
      question_score: this.props.question_score || this.props.init_question_score,
      question_title_error: false,
      standard_answers_error: false
    }
  }

  onSave = () => {
    const { question_title, question_score, standard_answers } = this.state;
    const { question_id_to_insert_after, question_id } = this.props
    const answerArray = standard_answers
    if (!question_title || !validateLength(question_title, 10000)) {
      this.setState({ question_title_error: true })
      this.props.showNotification(!question_title ? '题目：不能为空' : '题目不能超过10000字符');
      return;
    }
    if (!validateLength(standard_answers[0], 10000)) {
      this.setState({ standard_answers_error: true })
      this.props.showNotification('参考答案不能超过10000字符');
      return;
    }
    const intScore = parseFloat(question_score)
    if (intScore == 0) {
      this.props.showNotification('分值：必须大于0'); return;
    } else if (!question_score || intScore == NaN) {
      this.props.showNotification('分值：不能为空'); return;
    }
    /**
        {
    "question_title":"社会主义核心价值观是？.",
    "question_type":4,
    "question_score":5,
    "standard_answers":["富强，民主，自由。。。"]
}
    }*/
    const Id = this.props.match.params.Id
    if (question_id) {
      const editUrl = this.props.getEditQuestionUrl(question_id);
      axios.put(editUrl, {
        question_title,
        question_type: 4,
        question_score,
        standard_answers: answerArray,
        insert_id: question_id_to_insert_after || undefined
      })
        .then((response) => {
          if (response.data.status == 0) {
            this.props.addSuccess()
          }
        })
        .catch(function (error) {
          console.log(error);
        });
    } else {
      const url = this.props.getAddQuestionUrl();

      axios.post(url, {
        exercise_bank_id: Id,
        question_title,
        question_type: 4,
        question_score,
        standard_answers: answerArray,
        insert_id: question_id_to_insert_after || undefined
      })
        .then((response) => {
          if (response.data.status == 0) {
            this.props.addSuccess()
          }
        })
        .catch(function (error) {
          console.log(error);
        });
    }
  }
  onCancel = () => {
    this.props.onEditorCancel()
  }
  on_question_score_change = (e) => {
    this.setState({ question_score: e })
  }

  onSetQuestionTitle = (value) => {
    this.setState({
      question_title: value,
      question_title_error: false
    })
  }

  onSetAnswer = (value) => {
    this.setState({
      standard_answers: [value],
      standard_answers_error: false
    })
  }

  render() {
    let { question_title, question_score, question_type, standard_answers, standard_answers_error, question_title_error } = this.state;
    let { index, exerciseIsPublish, is_md } = this.props;
    const qNumber = `question_${index}`;

    return (
      <div className="padding20-30 bor-bottom-greyE" id={qNumber}>
        <style>{`
              .optionMdEditor {
                flex: 0 0 800px
              }
              .optionRow {
                margin: 2px;
              }
            `}</style>
        <p className="mb10 clearfix">
          {/*!question_id ? '新建' : '编辑'*/}
          <span className="color-blue font-16 mr20 fl">{qNameArray[question_type]}</span>
          <span className="color-grey-9 font-12 fl">（主观题，未作答的情况下自动评为零分）</span>
        </p>


        <CustomEditor is_md={is_md} height={is_md ? 155 : 109}
          placeholder="请您输入题目"
          value={question_title}
          isShowEditor={true}
          md_id='question-editor-1'
          isError={question_title_error}
          autoFocus={true}
          onChange={this.onSetQuestionTitle}
        />


        <div>
          <div className="mb10 font-16">参考答案</div>

          <CustomEditor is_md={is_md} height={is_md ? 155 : 109}
            placeholder="请您输入参考答案(可选)"
            value={standard_answers[0] || ''}
            md_id='answer-editor'
            isShowEditor={true}
            isError={standard_answers_error}
            autoFocus={true}
            onChange={this.onSetAnswer}
          />
        </div>

        <div className="mt10">
          分值：
              <InputNumber step={0.1} precision={1} min={0} max={100} style={{ width: 100 }} value={question_score} onChange={this.on_question_score_change}
            disabled={exerciseIsPublish}
          ></InputNumber> 分

              <span className="fr">
            <ActionBtn style="greyBack" className="middle mr20" onClick={this.onCancel}
            >取消</ActionBtn>
            <ActionBtn style="blue" className="middle" onClick={this.onSave}>保存</ActionBtn>
          </span>

        </div>

      </div>
    )
  }
}
// RouteHOC()
export default (MainEditor);