import React, {
  useState,
  useCallback,
  useEffect,
  useRef,
  useMemo,
  useContext,
  createContext,
} from "react";
import _ from "lodash";
import { Spin } from "antd";

export function useToggle(init = false) {
  const [bool, setBool] = useState(init);
  const toggle = useCallback(() => {
    setBool((old) => !old);
  }, []);
  return [bool, toggle];
}
export function useForceUpdate() {
  const [_, setVer] = useState(0);
  return useCallback(() => {
    setVer((v) => v + 1);
  }, []);
}
export function useMap(canAdd = () => true, canRemove = () => true) {
  const forceUpdate = useForceUpdate();
  return useMemo(() => {
    const map = new Map();
    map.set = function (k, v) {
      if (canAdd(this)) {
        Object.getPrototypeOf(this).set.call(this, k, v);
        forceUpdate();
      }
    };
    map.delete = function (k) {
      if (canRemove(this)) {
        Object.getPrototypeOf(this).delete.call(this, k);
        forceUpdate();
      }
    };
    return map;
  }, []);
}
export function useLoaded(promiseFac, dependsLst) {
  const [isLoaded, setLoaded] = useState(false);
  const dataRef = useRef(null);
  useEffect(() => {
    const f = async () => {
      dataRef.current = await promiseFac();
      if (dataRef.current) {
        setLoaded(true);
      }
    };
    f();
    return () => {
      setLoaded(false);
    };
  }, dependsLst);
  return { isLoaded, data: dataRef.current };
}

export const MockCtx = createContext(null);
export const HooksMocker = ({ children, ...props }) => {
  return (

    <MockCtx.Provider
      value={{
        history: props.history,
        params: props.match.params,
        location: props.location,
        props,
      }}
    >
      {children}
    </MockCtx.Provider>
  );
};

export const useDebounceState = (value, delay) => {
  const [v, setV] = useState(value);
  const debounceSetValue = useCallback(_.debounce(setV, delay), []);
  return [v, debounceSetValue];
};

export const useParams = () => {
  const { params } = useContext(MockCtx);
  return params;
};
export const useHistory = () => {
  const { history } = useContext(MockCtx);
  return history;
};
export const useLocation = () => {
  const { location } = useContext(MockCtx);
  return location;
};

export const useProps = () => {
  const { props } = useContext(MockCtx);
  return props;
};
