import React, { useCallback, useState } from "react";
import styled from "styled-components";
import Check from "./Check";
import _ from "lodash";
import { FontMixinGen } from "../cssMixin";
import { FlexBox } from "../layout";

const Container = styled(FlexBox)`
  div:first-child {
    ${FontMixinGen(12)}
    color: #717171;
  }
  align-items: flex-start;
  & ${Check} {
    &:not(:last-child) {
      margin-right: 25px;
    }
  }
  margin-bottom: 16px;
`;

const ItemContainer = styled(FlexBox)`
  flex-wrap: wrap;
  & > * {
    margin-right: 20px;
    margin-bottom: 5px;
  }
`;

const M = styled.div`
  &:not(:last-child) {
    margin-bottom: 14px;
  }
`;

export default ({ map, value, onChange, label }) => {
  const [isAll, setAll] = useState(true);
  if (value == undefined) {
    value = [...map.keys()];
  }
  const selectAll = useCallback((isChecked) => {
    if (isChecked) {
      onChange([...map.keys()]);
      setAll(true);
    }
  }, []);
  const select = useCallback((_isAll, isChecked, value, k) => {
    if (_isAll) {
      onChange([k]);
      setAll(false);
    } else if (isChecked) {
      onChange(_.concat(value, k));
    } else {
      if (value.length == 1) {
        onChange([...map.keys()]);
        setAll(true);
      } else {
        onChange(_.without(value, k));
      }
    }
  }, []);
  return (
    <React.Fragment>
      <Container>
        <div style={{ whiteSpace: "nowrap", marginRight: "10px" }}>
          {label}:
        </div>
        <ItemContainer>
          <Check value={isAll} onChange={selectAll} key={"全部"}>
            全部
          </Check>
          {[...map.entries()].map(([k, v]) => (
            <Check
              key={k}
              value={!isAll && value.includes(k)}
              onChange={(isChecked) => {
                select(isAll, isChecked, value, k);
              }}
            >
              {v}
            </Check>
          ))}
        </ItemContainer>
      </Container>
      <M />
    </React.Fragment>
  );
};
