import styled from "styled-components";
import React, { forwardRef, cloneElement, useState } from "react";
import classnames from "classnames";
import { FontMixinGen, AllCenterMixin, ExpandSizeMixin } from "../cssMixin";

const Input = forwardRef(
  ({ className, value, onChange, icon, ...props }, ref) => {
    const [isFocus, setFocus] = useState(false);
    return (
      <div className={className}>
        <input
          value={value}
          onChange={(e) => {
            onChange(e.target.value);
          }}
          onBlur={() => setFocus(false)}
          onFocus={() => setFocus(true)}
          ref={ref}
          {...props}
        />
        {icon && (
          <div className="icon-wrapper">
            {cloneElement(icon, {
              className: classnames(
                icon.props.className,
                { focus: isFocus },
                "icon"
              ),
            })}
          </div>
        )}
      </div>
    );
  }
);

export default styled(Input)`
  ${FontMixinGen(14)}
  position: relative;
  width: fit-content;
  :hover {
    input {
      border: 1px solid #1890ff;
    }
    .icon {
      color: #1890ff;
    }
  }
  input {
    outline-style: none;
    border: 1px solid #d9d9d9;
    border-radius: 2px;
    box-sizing: border-box;
    color: #111111;
    padding: 9px 9px;
    height: 32px;
    ::placeholder {
      color: rgba(0, 0, 0, 0.25);
    }
    :focus {
      border: 1px solid #2775ff;
    }
  }
  .icon-wrapper {
    position: absolute;
    ${ExpandSizeMixin}
    ${AllCenterMixin}
        justify-content:flex-end;
    top: 0px;
    pointer-events: none;
  }
  .icon {
    color: #666666;
    margin-right: 8px;
  }
  .icon.focus {
    color: #2775ff;
  }
`;
