import styled from "styled-components";
import { Icon } from "antd";
import { FontMixinGen, AllCenterMixin } from "../cssMixin";
import classnames from "classnames";
import React from "react";

const BaseDiv = ({ className, children, disable, onClick, ...props }) => (
  <div
    className={classnames({ disable }, className)}
    onClick={disable ? undefined : onClick}
    {...props}
  >
    {children}
  </div>
);

const CanDisableBtnBase = styled(BaseDiv)`
  ${FontMixinGen(14)}
  ${AllCenterMixin}
  border-radius: 2px;
  user-select: none;
  &:not(.disable):hover {
    cursor: pointer;
  }
  &.disable:hover {
    cursor: not-allowed;
  }
`;

export const IconBtn = styled(Icon)`
  display: block;
  color: black;
  &:active {
    color: #2775ff;
  }
  &:hover {
    color: #1890ff;
  }
`;

export const OutlineBtn = styled(CanDisableBtnBase)`
  padding: 0 14px;
  padding-top: 2px;
  height: 32px;
  color: rgba(0, 0, 0, 0.65);
  background: white;
  border: 1px solid rgba(0, 0, 0, 0.15);
  &:not(.disable):hover {
    background: rgba(24, 144, 255, 1);
    color: white;
  }
  &:not(.disable):active {
    background: rgba(39, 117, 255, 1);
    color: white;
  }
  &.disable {
    background: rgba(0, 0, 0, 0.04);
    color: rgba(0, 0, 0, 0.25);
  }
`;

export const CircleBtn = styled(CanDisableBtnBase)`
  font-weight: 500;
  width: 40px;
  height: 40px;
  border-radius: 50%;
  color: white;
  &:hover {
    color: white;
  }
  &.yellow {
    background: #fd8001;
    border: 1px solid #ffb162;
    &:hover {
      background: #ffbc78;
    }
    &:active {
      background: #e0770d;
    }
  }
  &.red {
    background: #fb3226;
    border: 1px solid #ff8b84;
    &:hover {
      background: #fc756d;
    }
    &:active {
      background: #e92216;
    }
  }
  &.green {
    background: #2abd8c;
    border: 1px solid #27aa7f;
    &:hover {
      background: #6fd499;
    }
    &:active {
      background: #16a150;
    }
  }
`;

export const OkBtn = styled(CanDisableBtnBase).attrs((_) => ({
  children: "是",
}))`
  width: 65px;
  height: 32px;
  background: rgba(255, 255, 255, 1);
  border: 1px solid rgba(0, 0, 0, 0.15);
  &:hover {
    background: rgba(230, 247, 255, 1);
    border: 1px solid rgba(145, 213, 255, 1);
    color: #1890ff;
  }
  &:active {
    background: rgba(230, 247, 255, 1);
    border: 1px solid rgba(39, 117, 255, 1);
    color: #2775ff;
  }
`;

export const PrimaryBtn = styled(CanDisableBtnBase)`
  background: rgba(24, 144, 255, 1);
  border: 1px solid rgba(0, 0, 0, 0.15);
  padding: 0 12px;
  padding-top:2px;
  color: white;
  &:not(.disable):hover {
    background: #4aa8ff;
    border: 1px solid rgba(145, 213, 255, 1);
  }
  &:not(.disable):active {
    background: #2775ff;
    border: 1px solid rgba(39, 117, 255, 1);
  }
  &.disable {
    background: rgba(0, 0, 0, 0.04);
    border: 1px solid rgba(0, 0, 0, 0.15);
    color: rgba(0, 0, 0, 0.25);
  }
`;

export const CancelBtn = styled(PrimaryBtn).attrs((_) => ({
  children: "否",
}))`
  width: 65px;
  height: 32px;
`;

export const TextBtn = styled(CanDisableBtnBase)`
  font-size:${p=>p.s};
  color: #1890ff;
  &.disable {
    color: #666666;
  }
  &:not(.disable):active {
    color: #2775ff;
  }
  &:not(.disable):hover {
    color: #4aa8ff;
  }
`;

export const ExitBtn = styled(CanDisableBtnBase)`
  background: rgba(255, 255, 255, 1);
  padding: 5px 16px;
  border: 1px solid rgba(0, 0, 0, 0.15);
  color: rgba(0, 0, 0, 0.65);
  &:hover {
    border: 1px solid rgba(255, 77, 79, 1);
  }
  &:active {
    background: rgba(255, 241, 240, 1);
    border: 1px solid rgba(255, 163, 158, 1);
  }
`;
