import React from "react";
import { Modal as AdModal } from "antd";
import styled from "styled-components";
import { FontMixinGen } from "../cssMixin";
import { FlexBox } from "../layout";
import { OkBtn, CancelBtn } from "./button";

const Title = styled.div`
  ${FontMixinGen(16)}
  font-weight:500;
  color: rgba(0, 0, 0, 0.85);
`;
const f = (p) => ({
  width: "480px",
  centered: true,
  maskClosable: false,
  footer: null,
  title: <Title>{p.title}</Title>,
});
const NormalModalBase = styled(AdModal).attrs(f)`
  &.ant-modal-content {
    background: rgba(255, 255, 255, 1);
    box-shadow: 0px 12px 48px 16px rgba(0, 0, 0, 0.03),
      0px 9px 28px 0px rgba(0, 0, 0, 0.05),
      0px 6px 16px -8px rgba(0, 0, 0, 0.08);
    border-radius: 2px;
    &.ant-modal-header {
      padding: 16px 24px;
    }
    &.ant-modal-body {
      padding: 0 0;
    }
  }
`;
const Container = styled.div`
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  align-items: center;
  height: 164px;
  & > div:first-child {
    margin-top: 28px;
    text-align: center;
    ${FontMixinGen(14)}
    color:rgba(0,0,0,0.65);
  }
  & > div:last-child {
    margin-bottom: 16px;
  }
`;
export const NormalModal = ({
  onOk,
  onCancel,
  onClose,
  children,
  ...props
}) => {
  if (!onClose) {
    onClose = onCancel;
  }
  return (
    <NormalModalBase {...{ ...props, onCancel: onClose }}>
      <Container>
        <div>{children}</div>
        <FlexBox>
          <OkBtn onClick={onOk} />
          <div style={{ width: "16px" }} />
          <CancelBtn onClick={onCancel} />
        </FlexBox>
      </Container>
    </NormalModalBase>
  );
};
