import "../css/Signinstatistics.css";
import React, { Component } from "react";
import { Row, Col, Card, Select } from "antd";
import { getImageUrl } from "educoder";
import axios from "axios";
import NoneDatas from "../component/NoneDatas";
import LoadingSpin from "../../../../common/LoadingSpin";
import echarts from "../../../../components/equire-echarts";
const { Option } = Select;

const chartsOption = {
  tooltip: {
    trigger: "axis",
    formatter: (param) => {
      let name = JSON.parse(param[0].name).name;
      if (name.length > 8) {
        name = name.substr(0, 5) + "...";
      }
      const date = JSON.parse(param[0].name).date;
      const title = `<div>${name} ${date}</div>`;
      const value = param.map((item) => {
        return `<div>${item.marker}${item.seriesName}: ${item.value}%</div>`;
      });
      return title + value.join("");
    },
  },
  legend: {
    data: ["到课率", "旷课率", "请假率"],
    show: false,
  },
  xAxis: {
    type: "category",
    boundaryGap: false,
    data: [],
    axisLabel: {
      formatter: (value) => {
        return JSON.parse(value).val;
      },
    },
  },
  yAxis: {
    type: "value",
    axisLabel: {
      formatter: "{value}%",
    },
    splitLine: {
      lineStyle: {
        type: "dashed",
      },
    },
  },
  series: [
    {
      name: "到课率",
      type: "line",
      smooth: true,
      data: [],
      extra: [],
      color: "#26C7C9",
    },
    {
      name: "旷课率",
      type: "line",
      smooth: true,
      data: [],
      color: "#FF835C",
    },
    {
      name: "请假率",
      type: "line",
      smooth: true,
      data: [],
      color: "#EDBA6F",
    },
    {
      name: "时间",
      type: "line",
      smooth: true,
      data: [],
      color: "#EDBA6F",
    },
  ],
};
class Signinstatistics extends Component {
  constructor(props) {
    super(props);
    this.state = {
      datas: null,
      newlist: undefined,
      course_groups: [{ id: "全部", name: "全部" }],
      spal: false,
    };
  }
  getdata = (group_id) => {
    const coursesId = this.props.match.params.coursesId;
    let url = `/weapps/courses/${coursesId}/attendances.json`;
    axios
      .get(url, {
        params: {
          group_id: group_id === "全部" ? undefined : group_id,
        },
      })
      .then((response) => {
        if (response) {
          if (response.data) {
            const newlists = response.data.history_attendances;
            chartsOption.series.map((serie) => {
              serie.data = [];
            });
            chartsOption.xAxis.data = [];
            if (response.data.history_attendances.length > 0) {
              response.data.history_attendances.map((item, key) => {
                chartsOption.series[0].data.push(
                  (item.normal_rate * 100).toFixed(0)
                );
                chartsOption.series[1].data.push(
                  (item.absence_rate * 100).toFixed(0)
                );
                chartsOption.series[2].data.push(
                  (item.leave_rate * 100).toFixed(0)
                );
                chartsOption.xAxis.data.push(
                  JSON.stringify({
                    name: item.name,
                    date:
                      item.attendance_date +
                      " " +
                      item.start_time +
                      "-" +
                      item.end_time,
                    val: key + 1,
                  })
                );
              });
            }

            this.setState({
              datas: response.data,
              newlist: newlists,
            });
          }
        }
        this.setState({
          spal: false,
        });
        const signInCharts = echarts.init(
          document.getElementById("signInCharts")
        );
        signInCharts.setOption(chartsOption);
      })
      .catch((error) => {
        this.setState({
          spal: false,
        });
      });
  };

  componentDidMount() {
    this.setState({
      spal: true,
    });
    const coursesId = this.props.match.params.coursesId;
    let newurl = `/courses/${coursesId}/all_course_groups.json`;
    axios.get(newurl).then((response) => {
      let newlist = this.state.course_groups;
      response.data.course_groups.map((item, key) => {
        newlist.push(item);
      });
      this.setState({
        course_groups: newlist,
      });
    });

    this.getdata();
  }

  handleChange = (value) => {
    this.getdata(value);
  };

  render() {
    let { datas, newlist, course_groups, spal } = this.state;
    return (
      <React.Fragment>
        <div>
          {spal === true ? (
            <div
              style={{
                minHeight: "500px",
              }}
            >
              <LoadingSpin></LoadingSpin>
            </div>
          ) : (
            <div>
              <Row type="flex" justify="space-between" className={"mt20"}>
                <style>
                  {`
              .lishiqiandao{
                background-image: url(${getImageUrl(
                  `images/qiandao/lishi.png`
                )});
              }
                  .daokeqiandao{
                background-image: url(${getImageUrl(
                  `images/qiandao/daoke.png`
                )});
              }
                  .kuangkeqiandao{
                background-image: url(${getImageUrl(
                  `images/qiandao/kuangke.png`
                )});
              }
                  .qingjiaqiandao{
                background-image: url(${getImageUrl(
                  `images/qiandao/qingjia.png`
                )});
              }
              `}
                </style>
                <Col span={6}>
                  <Card
                    style={{ width: 209 }}
                    className={"gutterrowbox lishiqiandao"}
                  >
                    <div className={"gutterrowboxcontent ml5"}>
                      {datas && datas.all_history_count}
                    </div>
                  </Card>
                </Col>
                <Col span={6}>
                  <Card
                    style={{ width: 209 }}
                    className={"ml8 gutterrowbox daokeqiandao"}
                  >
                    <div className={"gutterrowboxcontent ml5"}>
                      {datas
                        ? (datas && datas.avg_normal_rate * 100).toFixed(0) +
                          "%"
                        : ""}
                    </div>
                  </Card>
                </Col>
                <Col span={6}>
                  <Card
                    style={{ width: 209 }}
                    className={"ml14 gutterrowbox kuangkeqiandao"}
                  >
                    <div className={"gutterrowboxcontent ml5"}>
                      {datas
                        ? (datas && datas.avg_absence_rate * 100).toFixed(0) +
                          "%"
                        : ""}
                    </div>
                  </Card>
                </Col>
                <Col span={6}>
                  <Card
                    style={{ width: 209 }}
                    className={"ml20 gutterrowbox qingjiaqiandao"}
                  >
                    <div className={"gutterrowboxcontent ml5"}>
                      {datas
                        ? (datas && datas.avg_leave_rate * 100).toFixed(0) + "%"
                        : ""}
                    </div>
                  </Card>
                </Col>
              </Row>
              <div className={"mt20 pd30 edu-back-white"}>
                <Row>
                  <Col span={14}>
                    <Row type="flex" justify="start">
                      <Col span={5}>
                        <Row>
                          <Col span={12} className={"mindaoke mr5"}></Col>
                          <Col>到课率</Col>
                        </Row>
                      </Col>
                      <Col span={5}>
                        <Row>
                          <Col span={12} className={"minkuangke mr5"}></Col>
                          <Col>旷课率</Col>
                        </Row>
                      </Col>
                      <Col span={5}>
                        <Row>
                          <Col span={12} className={"minqingjia mr5"}></Col>
                          <Col>请假率</Col>
                        </Row>
                      </Col>
                    </Row>
                  </Col>
                  <Col span={10}>
                    <Row type="flex" justify="end">
                      <Col span={8} className={"Signinstatisticsfont"}>
                        显示最近十次签到
                      </Col>
                      <Col span={10}>
                        <Select
                          defaultValue={"全部"}
                          onChange={(e) => this.handleChange(e)}
                          style={{ width: "130px" }}
                          className={"Signinstatisticsfontselect"}
                        >
                          {course_groups &&
                            course_groups.map((item, key) => {
                              return (
                                <Option value={item.id} title={item.name}>
                                  {item.name}
                                </Option>
                              );
                            })}
                        </Select>
                      </Col>
                    </Row>
                  </Col>
                </Row>
              </div>
              {newlist && newlist.length > 0 ? (
                <div className={"SigninstatisticsChart"}>
                  <div
                    id="signInCharts"
                    style={{ height: 400, width: "100%" }}
                  ></div>
                </div>
              ) : (
                <div
                  style={{
                    minHeight: "400px",
                  }}
                >
                  <NoneDatas></NoneDatas>
                </div>
              )}
            </div>
          )}
        </div>
      </React.Fragment>
    );
  }
}

export default Signinstatistics;
