import React from "react";
import {
  Form,
  Input,
  InputNumber,
  Radio,
  Dropdown,
  Button,
  Card,
  Icon,
  message,
} from "antd";
import styled from "styled-components";
import FooterLink from "./components/FooterLink";

export const numberFormatter = (number) => {
  if (!number || Number.isNaN(Number(number))) {
    return "";
  } else {
    return Math.ceil(number);
  }
};
const RadioButton = styled(Radio.Button)`
  &.ant-radio-button-wrapper {
    width: 106px;
    height: 33px;
    text-align: center;
    margin-top: 6px;
    border-radius: 17px;
    background: #eeeeee;
    outline: none;
  }
  &.ant-radio-button-wrapper-checked {
    background: #4cacff;
    color: #ffffff;
  }
  &.ant-radio-button-wrapper-checked:focus-within {
    outline: none !important;
  }
  .ant-radio-button {
    text-align: center;
  }
  &.ant-radio-button-wrapper:not(:first-child)::before {
    width: 0px !important;
    border-radius: 17px;
  }
`;

class BaseInfo extends React.Component {
  subDisciplinesAdd = (item) => {
    const subDisciplinesList =
      this.props.form.getFieldValue("subDisciplines") || [];
    if (
      subDisciplinesList.filter(
        (subDisciplines) => item.id === subDisciplines.id
      ).length > 0
    ) {
      message.error("您已经选择过此方向！");
    } else {
      this.props.form.setFieldsValue({
        subDisciplines: [...subDisciplinesList, item],
      });
    }
  };

  disciplinesRemove = (discipline) => {
    const subDisciplinesList =
      this.props.form.getFieldValue("subDisciplines") || [];
    this.props.form.setFieldsValue({
      subDisciplines: subDisciplinesList.filter(
        (item) => item.id !== discipline.id
      ),
    });
  };
  handleSourceRadioChange = (e) => {
    this.props.getdisciplines(e.target.value);
    this.props.form.setFieldsValue({
      subDisciplines: [],
    });
  };
  render() {
    const { disciplines, form } = this.props;
    const { getFieldDecorator, getFieldValue } = form;
    const subDisciplinesList = getFieldValue("subDisciplines") || [];
    return (
      <Form>
        <Form.Item label="试卷名称:">
          {getFieldDecorator("name", {
            rules: [{ required: true, message: "试卷名称不能为空" }],
          })(
            <Input
              style={{ height: 38 }}
              placeholder="请输入试卷标题，最多60字"
              suffix={
                getFieldValue("name")
                  ? getFieldValue("name").length + "/60"
                  : "0/60"
              }
              maxLength={60}
            />
          )}
        </Form.Item>
        <Form.Item label="考试时长:">
          {getFieldDecorator("time", {
            rules: [{ required: true, message: "考试时长不能为空" }],
          })(
            <InputNumber
              min={1}
              max={9999}
              formatter={numberFormatter}
              placeholder="请输入试卷考试时长"
              style={{ width: 150 }}
            />
          )}
          <span style={{ marginLeft: 8 }}>分钟</span>
        </Form.Item>
        <Form.Item label="难度">
          {getFieldDecorator("difficulty", {
            rules: [{ required: true, message: "请选择难度" }],
          })(
            <Radio.Group
              style={{
                display: "flex",
                width: 400,
                justifyContent: "space-between",
                marginBottom: 6,
              }}
              buttonStyle="solid"
            >
              <RadioButton value={1}>简单</RadioButton>
              <RadioButton value={2}>适中</RadioButton>
              <RadioButton value={3}>困难</RadioButton>
            </Radio.Group>
          )}
        </Form.Item>
        <Form.Item label="试题来源">
          {getFieldDecorator("source", {
            rules: [{ required: true, message: "请选择试题来源" }],
            initialValue: 1,
          })(
            <Radio.Group
              style={{
                display: "flex",
                width: 700,
                justifyContent: "space-between",
              }}
              onChange={(e) => {
                this.handleSourceRadioChange(e);
              }}
            >
              <Radio value={1}>仅私有题库</Radio>
              <Radio value={0}>公共题库+私有题库</Radio>
              <span style={{ color: "#999" }}>
                （为保证考察准确性，建议使用私有题库）
              </span>
            </Radio.Group>
          )}
        </Form.Item>
        <Form.Item label="考查范围：">
          {getFieldDecorator("subDisciplines", {
            rules: [{ required: true, message: "请选择考查范围" }],
          })(
            <div style={{ display: "flex", flexWrap: "wrap" }}>
              {disciplines.map((discipline) => {
                return (
                  <Dropdown
                    key={"disciplines" + discipline.id}
                    placement="bottomLeft"
                    overlay={
                      <Card
                        style={{
                          maxWidth: 600,
                          display: "flex",
                          msFlexDirection: "row",
                          flexWrap: "warp",
                          justifyContent: "center",
                        }}
                      >
                        {discipline.sub_disciplines.length > 0
                          ? discipline.sub_disciplines.map((item) => {
                              return (
                                <div
                                  style={{
                                    display: "inline-block",
                                    margin: "6px 12px",
                                  }}
                                  key={"sub_disciplines" + item.id}
                                >
                                  <a
                                    className={"color-dark"}
                                    onClick={() => {
                                      this.subDisciplinesAdd(item);
                                    }}
                                  >
                                    {item.name}
                                  </a>
                                </div>
                              );
                            })
                          : "暂无数据"}
                      </Card>
                    }
                  >
                    <Button
                      style={{ marginRight: 12, marginTop: 6, marginBottom: 6 }}
                    >
                      {discipline.name}
                    </Button>
                  </Dropdown>
                );
              })}
            </div>
          )}
        </Form.Item>
        {subDisciplinesList.length > 0 ? (
          <div style={{ minHeight: 150, backgroundColor: "#FAFAFA" }}>
            <div style={{ paddingLeft: 12, paddingTop: 12 }}>已选</div>
            <div style={{ display: "flex", flexWrap: "wrap" }}>
              {subDisciplinesList.map((discipline) => {
                return (
                  <div key={"subDisciplinesList" + discipline.id}>
                    <Button
                      style={{ margin: "12px 6px", backgroundColor: "#F6FFED" }}
                      onClick={() => {
                        this.disciplinesRemove(discipline);
                      }}
                    >
                      {discipline.name}
                      <Icon type="close-circle" />
                    </Button>
                  </div>
                );
              })}
            </div>
          </div>
        ) : null}
        <FooterLink />
      </Form>
    );
  }
}
export default BaseInfo;
