import React from "react";
import { Breadcrumb, Button, Card, Divider, Spin, message } from "antd";
import Axios from "axios";
import { SnackbarHOC } from "educoder";
import TPMIndexHOC from "../../tpm/TPMIndexHOC";
import styled from "styled-components";
import { questionType, difficultType } from "./index";
import { Link } from "react-router-dom";
import SendTopicsModel from "../../testpaper/component/SendTopicsModel";

const mock = {
  examination_bank: {
    name: "测试随机组卷接口",
    difficulty: 1,
    public: false,
    time: 60,
    source: 1,
    is_random: true,
    sub_discipline_id: null,
  },
  contents: [
    {
      item_type: "SINGLE",
      difficulty: 1,
      sub_discipline_id: 12,
      quanlity: 3,
    },
  ],
  score_settings: [
    {
      item_type: "SINGLE",
      score: 5,
    },
  ],
  all_sub_disciplines: [
    {
      sub_discipline_id: 12,
      sub_discipline_name: "Java程序设计",
    },
  ],
};
const Badge = styled.span`
  width: 40px;
  height: 20px;
  background: rgba(230, 247, 255, 1);
  border-radius: 10px;
  border: 1px solid rgba(145, 213, 255, 1);
  margin-left: 8px;
  color: #1890ff;
  font-size: 12px;
  font-weight: 400;
  padding: 4px;
  display: flex;
  justify-content: center;
  align-items: center;
`;
const indexArr = ["一", "二", "三", "四", "五", "六", "七", "八", "九", "十"];
class RandomPaperDetail extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      loading: false,
      contents: [],
      examination_bank: {},
      score_settings: [],
      modalVisible: false,
      id: "161",
    };
  }
  componentDidMount() {
    this.getPaperData();
    // const { contents, examination_bank, score_settings } = mock;
    // this.setState({ contents, examination_bank, score_settings });
  }
  getPaperData = () => {
    const id = window.location.href.split("/").pop();
    this.setState({ loading: true, id });
    Axios.get(`/examination_banks/${id}/edit_random_exam.json`).then((res) => {
      this.setState({ loading: false });
      if (res.status === 200) {
        const { contents, examination_bank, score_settings } = res.data;
        this.setState({ contents, examination_bank, score_settings });
      } else {
        message.error("获取试卷信息错误");
      }
    });
  };

  render() {
    const { contents, examination_bank, score_settings, loading } = this.state;
    let count = []; //记录有哪些题型，数量
    let totalScore = 0; //总分
    let totalCount = 0; //总小题数
    Object.keys(questionType).map((key) => {
      let num = 0;
      contents.map((item) => {
        if (item.item_type === key) {
          num += item.quanlity;
        }
      });
      const scoreItem = score_settings.filter((v) => v.item_type === key);
      count = [
        ...count,
        {
          item_type: key,
          num: num,
          score: scoreItem.length > 0 ? scoreItem[0].score : 0,
        },
      ];
    });
    const allcount = count.filter((item) => item.num !== 0); //num不为0的大题数组  [{item_type:"MUTIPLY",num:1,score:4}]
    allcount.map((item) => {
      score_settings.map((item1) => {
        if (item.item_type === item1.item_type) {
          totalScore += item.num * item1.score;
          totalCount += item.num;
        }
      });
    });
    const CardTitle = (
      <div
        style={{
          display: "flex",
          justifyContent: "space-between",
          alignItems: "center",
        }}
      >
        <div
          style={{
            display: "flex",
            justifyContent: "space-between",
            width: "50%",
          }}
        >
          <span>
            总计 {allcount.length} 大题， {totalCount} 小题，总分 {totalScore}{" "}
            分
          </span>
          <span>考试时长： {examination_bank.time} 分钟</span>
          <span>试卷难度：{difficultType[examination_bank.difficulty]}</span>
        </div>
        <div>
          <Button
            type="primary"
            onClick={() => this.setState({ modalVisible: true })}
          >
            发送至课堂
          </Button>
        </div>
      </div>
    );
    return (
      <div style={{ width: 1200, margin: "0px auto" }}>
        <Spin spinning={this.state.loading}>
          <Breadcrumb separator=">" style={{ padding: "12px 0px" }}>
            <Breadcrumb.Item>试卷库</Breadcrumb.Item>
            <Breadcrumb.Item>
              <Link to="/paperlibrary">我的试卷库</Link>
            </Breadcrumb.Item>
            <Breadcrumb.Item>试卷查看</Breadcrumb.Item>
          </Breadcrumb>
          <div style={{ height: 50, display: "flex", alignItems: "center" }}>
            <span
              style={{
                fontSize: 20,
                fontWeight: 600,
              }}
            >
              <i
                className="icon-leftarrow iconfont"
                style={{
                  fontSize: 14,
                  marginRight: 8,
                  cursor: "pointer",
                }}
                onClick={()=>{
                  this.props.history.goBack()
                }}
              ></i>
              {examination_bank.name}
            </span>
            <Badge>随机</Badge>
          </div>
          <Card title={CardTitle} style={{ marginBottom: 200 }}>
            {allcount.map((item, index) => {
              //去重的二级菜单目录 subIds
              const subIds = Array.from(
                new Set(
                  contents
                    .map((content) => {
                      if (content.item_type === item.item_type) {
                        return content.sub_discipline_id;
                      }
                      return null;
                    })
                    .filter((i) => i)
                )
              );

              return (
                <div>
                  <div style={{ color: "#1890FF" }}>
                    {indexArr[index]}、{questionType[item.item_type]}
                    <span style={{ color: "#666666", marginLeft: 5 }}>
                      (共 {item.num} 题，每题 {item.score} 分)
                    </span>
                  </div>
                  <div>
                    {subIds.map((id) => {
                      //contentArr 当前大题、当前二级目录 所有的难度
                      const contentArr = contents.filter(
                        (content) =>
                          content.sub_discipline_id === id &&
                          item.item_type === content.item_type
                      );
                      return (
                        <div style={{ marginTop: 20, display: "flex" }}>
                          <div style={{ width: "30%", fontWeight: "600" }}>
                            <span>{`${contentArr[0].discipline_name} /
                          ${contentArr[0].sub_discipline_name}`}</span>
                          </div>
                          <div>
                            {Object.keys(difficultType).map((difficulty) => {
                              let dnum = 0;
                              contentArr.map((content) => {
                                if (content.difficulty == difficulty) {
                                  dnum = content.quanlity;
                                }
                                return null;
                              });
                              return dnum > 0 ? (
                                <span style={{ color: "#1890FF",marginLeft:30 }}>
                                  {difficultType[difficulty]}: {dnum} 题
                                </span>
                              ) : null;
                            })}
                          </div>
                        </div>
                      );
                    })}
                  </div>
                  {index === allcount.length - 1 ? null : <Divider />}
                </div>
              );
            })}
          </Card>
          <SendTopicsModel
            paramsid={this.state.id}
            visible={this.state.modalVisible}
            mypaper={false}
            {...this.state}
            {...this.props}
            submitInfos={(modalVisible, id) => {
              this.setState({ modalVisible, id });
            }}
          ></SendTopicsModel>
        </Spin>
      </div>
    );
  }
}
export default SnackbarHOC()(TPMIndexHOC(RandomPaperDetail));
