import React from "react";
import { Form, InputNumber } from "antd";
import { numberFormatter } from "./BaseInfo";
import { questionType } from "./index";
import styled from "styled-components";

const Label = ({ title, score, totalCount }) => {
  return (
    <div>
      {title}:
      {score && score > 0 ? (
        <span style={{ marginLeft: 4, color: "#999", fontSize: 12 }}>
          {/* (已选 {totalCount} 题,共 {score} 分)  */}
          (共 {score} 分)
        </span>
      ) : null}
    </div>
  );
};
const FormItem = styled(Form.Item)`
  & .ant-form-item-required {
    display: flex;
  }
  & .ant-form-item-required::before {
    line-height: 41px;
  }
`;
class ScoreSetting extends React.Component {
  constructor(props) {
    super(props);
    this.state = {};
  }
  render() {
    const { form } = this.props;
    const { getFieldDecorator, getFieldsValue } = form;
    // SINGLE: "单选题",
    // MULTIPLE: "多选题",
    // JUDGMENT: "判断题",
    // COMPLETION: "填空题",
    // SUBJECTIVE: "简答题",
    // PRACTICAL: "实训题",
    // PROGRAM: "编程题",
    const questionTypeArr = Object.keys(questionType);
    const formData = getFieldsValue();
    let totalScore = 0; //试卷总分

    return (
      <Form>
        {questionTypeArr.map((question) => {
          const totalKeys = Object.keys(formData).filter(
            (key) => key.includes(`${question}-`) && formData[key]
          );
          let totalCount = 0; //当类型前题目总数
          let TypeScore = 0; //当前类型题目的总分
          totalKeys.map((key) => {
            totalCount += formData[key];
            TypeScore = totalCount * formData[`score-${question}`];
            return null;
          });
          totalScore += TypeScore;
          if (totalKeys.length > 0) {
            return (
              <FormItem
                label={
                  <Label
                    title={questionType[question]}
                    score={TypeScore}
                    totalCount={totalCount}
                  />
                }
                colon={false}
                key={questionType[question]}
              >
                {getFieldDecorator(`score-${question}`, {
                  rules: [{ required: true, message: "分数不能为空" }],
                })(
                  <InputNumber
                    min={1}
                    max={100}
                    formatter={numberFormatter}
                    placeholder="请输入试题分数设置"
                    style={{ width: 150 }}
                  />
                )}
                <span style={{ marginLeft: 8 }}>分/题</span>
              </FormItem>
            );
          } else {
            return null;
          }
        })}
        {totalScore && totalScore > 0 ? (
          <div style={{ marginTop: 16 }}>
            当前本卷总分<span style={{ color: "#1890FF" }}> {totalScore} </span>
            分
          </div>
        ) : null}
      </Form>
    );
  }
}
export default ScoreSetting;
