import React from "react";
import { Form, InputNumber } from "antd";
import { numberFormatter } from "../BaseInfo";
import { questionType, difficultType } from "../index";

class Selector extends React.Component {
  render() {
    const {
      getFieldDecorator,
      getFieldsValue,
      setFieldsValue,
    } = this.props.form;
    const { item_type, items_by_item_type } = this.props.data;
    const FormItemLabel = ({ difficult, count }) => (
      <div style={{ marginRight: 10, lineHeight: "18px" }}>
        <div style={{ fontSize: 14, textAlign: "left" }}>
          {difficultType[difficult]}
        </div>
        <div style={{ fontSize: 12, color: "#999999" }}>
          (共 {count} 题可选)
        </div>
      </div>
    );
    const formData = getFieldsValue();
    const totalKeys = Object.keys(formData).filter(
      (key) => key.includes(`${item_type}-`) && formData[key]
    );
    let totalCount = 0;
    totalKeys.map((key) => {
      totalCount += formData[key];
      return null;
    });

    return (
      <div>
        <div>
          {questionType[item_type]}
          {numberFormatter(totalCount) > 0 ? (
            <span style={{ color: "#999999", fontSize: 12 }}>
              （已选 {numberFormatter(totalCount)} 题）
            </span>
          ) : null}
        </div>
        {items_by_item_type.map((item) => (
          <div key={item_type + item.discipline_id + item.sub_discipline_id}>
            <div
              style={{ fontSize: 16, margin: "16px 0px", fontWeight: "500" }}
            >
              {item.discipline_name} / {item.sub_discipline_name}
            </div>
            <div>
              {item.items_by_item_type_and_sub_discipline.map((items) => {
                return (
                  <Form.Item
                    label={
                      <FormItemLabel
                        count={items.items_count}
                        difficult={items.difficulty}
                      />
                    }
                    colon={false}
                    style={{ width: "30%" }}
                    key={`${item_type}-${item.sub_discipline_id}-${items.difficulty}`}
                  >
                    {getFieldDecorator(
                      `count-${item_type}-${item.sub_discipline_id}-${items.difficulty}`, //example: count-MULTIPLE-1-1
                      {
                        initialValue: 0,
                      }
                    )(
                      <InputNumber
                        min={0}
                        max={items.items_count}
                        formatter={numberFormatter}
                      />
                    )}
                    <span style={{ marginLeft: 8 }}>题</span>
                  </Form.Item>
                );
              })}
            </div>
          </div>
        ))}
      </div>
    );
  }
}

export default Selector;
