import React from "react";
import {
    Breadcrumb,
    Button,
    Steps,
    Card,
    Divider,
    Form,
    Spin,
    message,
} from "antd";
import { SnackbarHOC } from "educoder";
import TPMIndexHOC from "../../tpm/TPMIndexHOC";
import BaseInfo from "./BaseInfo";
import Axios from "axios";
import qs from "qs";
import QuestionCount from "./QuestionCount";
import ScoreSetting from "./ScoreSetting";
import { Link } from "react-router-dom";

const { Step } = Steps;
export const questionType = {
    SINGLE: "单选题",
    MULTIPLE: "多选题",
    JUDGMENT: "判断题",
    COMPLETION: "填空题",
    SUBJECTIVE: "简答题",
    PRACTICAL: "实训题",
    PROGRAM: "编程题",
};

export const difficultType = {
    1: "简单",
    2: "适中",
    3: "困难",
};

class IntelligentPaper extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            current: 0,
            disciplines: [],
            loading: false,
            optinalData: [], //可选题目数据
            countData: {},
            scoreData: {},
        };
    }

    componentDidMount() {
        if (window.location.href.includes("/randompaper/edit")) {
            this.getPaperData();
            this.idEdit = true;
        } else {
            this.getdisciplines();
        }
    }

    componentWillMount() {
        // 拦截判断是否离开当前页面
        window.addEventListener("beforeunload", this.beforeunload);
    }

    componentWillUnmount() {
        // 销毁拦截判断是否离开当前页面
        window.removeEventListener("beforeunload", this.beforeunload);
    }

    beforeunload(e) {
        let confirmationMessage = "确定离开此页面吗?此页数据可能会丢失";
        (e || window.event).returnValue = confirmationMessage;
        return confirmationMessage;
    }

    getPaperData = () => {
        const id = window.location.href.split("/").pop();
        this.setState({ loading: true });
        Axios.get(`/examination_banks/${id}/edit_random_exam.json`).then((res) => {
            this.setState({ loading: false });
            if (res.status === 200) {
                const {
                    contents,
                    examination_bank,
                    score_settings,
                    all_sub_disciplines,
                } = res.data;
                let countData = {}; //第二步的数据 先存起来，等获取完题目数量渲染之后再给input复制
                let scoreData = {}; //第三步
                contents.map((item) => {
                    countData = {
                        ...countData,
                        [`count-${item.item_type}-${item.sub_discipline_id}-${item.difficulty}`]: item.quanlity,
                    };
                    return null;
                });
                score_settings.map((item) => {
                    scoreData = {
                        ...scoreData,
                        [`score-${item.item_type}`]: item.score,
                    };
                    return null;
                });
                this.props.form.setFieldsValue({
                    ...examination_bank,
                    subDisciplines: all_sub_disciplines.map((item) => {
                        return {
                            id: item.sub_discipline_id,
                            name: item.sub_discipline_name,
                        };
                    }),
                });
                this.setState({ countData, scoreData });
                const { source } = examination_bank;
                this.getdisciplines(source);
            } else {
                message.error("获取试卷信息错误");
            }
        });
    };
    getdisciplines = (source = 1) => {
        let url = "/disciplines.json";
        Axios.get(url, {
            params: {
                source: "question",
                public: source,
            },
        })
            .then((result) => {
                if (result.status == 200) {
                    this.setState({
                        disciplines: result.data.disciplines,
                    });
                }
            })
            .catch((error) => {
                console.log(error);
            });
    };
    getQuestionNumbers = () => {
        this.setState({ loading: true });
        const ids = this.props.form
            .getFieldValue("subDisciplines")
            .map((item) => item.id);
        const source = this.props.form.getFieldValue("source");
        Axios.post("/examination_intelligent_settings/optinal_items.json", {
            sub_discipline_ids: ids,
            source: source === 1 ? 0 : 2,
        }).then((res) => {
            this.setState({ loading: false });
            if (res.status === 200) {
                this.setState({ optinalData: res.data.contents });
                this.props.form.setFieldsValue({
                    ...this.state.countData,
                });
            }
        });
    };
    //TODO:存 localstorage
    next = () => {
        const current = this.state.current + 1;
        if (this.state.current === 0) {
            this.props.form.validateFields(
                ["name", "time", "difficulty", "source", "subDisciplines"],
                (errors, values) => {
                    if (errors) {
                        return;
                    } else {
                        this.setState({ current });
                        this.getQuestionNumbers();
                    }
                }
            );
        } else if (this.state.current === 1 && this.idEdit) {
            this.props.form.setFieldsValue({
                ...this.state.scoreData,
            });
            this.setState({ current });
        } else if (this.state.current === 1) {
            let count = 0;
            let values = this.props.form.getFieldsValue()
            const { name, difficulty, time, source, subDisciplines, ...others } = values;
            Object.keys(others).forEach(value => {
                if (others[value] > 0) {
                    ++count
                }
            })
            if (count === 0) {
                message.error("请填写题型数量");
            } else {
                this.setState({ current });
            }
        }
    };

    prev = () => {
        const current = this.state.current - 1;
        this.setState({ current });
    };
    submit = () => {
        const data = this.props.form.getFieldsValue();
        this.props.form.validateFields((errors, values) => {
            debugger
            if (errors) {
                return;
            } else {
                const { name, difficulty, time, source, ...others } = values;
                const scoreSettings = [];
                const contents = [];
                Object.keys(others).map((key) => {
                    // count-MULTIPLE-1-1
                    if (key.includes("count")) {
                        const itemType = key.split("-")[1];
                        const subDisciplineId = key.split("-")[2];
                        const difficulty = key.split("-")[3];
                        if (values[key] !== 0) {
                            contents.push({
                                item_type: itemType,
                                difficulty: difficulty,
                                sub_discipline_id: subDisciplineId,
                                items_count: values[key],
                            });
                        }
                    } else if (key.includes("score")) {
                        const itemType = key.split("-")[1];
                        scoreSettings.push({
                            item_type: itemType,
                            score: values[key],
                        });
                    }
                    return null;
                });
                const data = {
                    name,
                    difficulty,
                    time,
                    source,
                    score_settings: scoreSettings,
                    contents,
                };
                if (this.idEdit) {
                    this.updatePaper(data);
                } else {
                    this.createPaper(data);
                }
            }
        });
    };
    createPaper = (data) => {
        this.setState({ loading: true });
        Axios.post("/examination_banks/create_random_exam.json", {
            ...data,
        }).then((res) => {
            this.setState({ loading: false });
            if (res.status === 200) {
                message.success("创建成功");
                this.props.history.push("/paperlibrary");
            }
        });
    };
    updatePaper = (data) => {
        this.setState({ loading: true });
        const id = window.location.href.split("/").pop();
        Axios.post(`/examination_banks/${id}/update_random_exam.json`, {
            ...data,
        }).then((res) => {
            this.setState({ loading: false });
            if (res.status === 200) {
                message.success("编辑成功");
                this.props.history.push("/paperlibrary");
            }
        });
    };
    confirm = (url) => {
        if (window.confirm("确定离开此页面吗?此页数据可能会丢失")) {
            if (url) {
                this.props.history.push(url);
            } else {
                // this.props.history.goBack();
                this.props.history.push("/paperlibrary");
            }
        }
    };

    render() {
        const { form } = this.props;
        const { current, disciplines } = this.state;
        const BackButton = (
            <Button
                onClick={() => {
                    this.confirm();
                }}
                style={{ marginRight: 16 }}
            >
                返回
            </Button>
        );
        const NextButton = (
            <Button type="primary" onClick={() => this.next()}>
                下一步
            </Button>
        );
        const PrevButton = (
            <Button onClick={() => this.prev()} style={{ marginRight: 16 }}>
                上一步
            </Button>
        );
        const SubmitButton = (
            <Button onClick={() => this.submit()} type="primary">
                完成组卷
            </Button>
        );
        const steps = [
            {
                title: "基本信息",
                content: (
                    <BaseInfo
                        disciplines={disciplines}
                        getdisciplines={this.getdisciplines}
                        form={form}
                    />
                ),
            },
            {
                title: "题型数量",
                content: (
                    <QuestionCount form={form} optinalData={this.state.optinalData} />
                ),
            },
            {
                title: "赋分设置",
                content: <ScoreSetting form={form} />,
            },
        ];
        return (
            <div style={{ width: 1200, margin: "0px auto" }}>
                <Breadcrumb separator=">" style={{ padding: "12px 0px" }}>
                    <Breadcrumb.Item>
                        <Link
                            to="/paperlibrary"
                            onClick={(e) => {
                                e.preventDefault();
                                this.confirm("/paperlibrary")
                            }}
                        >
                            试卷库
                        </Link>
                    </Breadcrumb.Item>
                    <Breadcrumb.Item>随机组卷</Breadcrumb.Item>
                </Breadcrumb>
                <div style={{ display: "flex", justifyContent: "space-between" }}>
                    <span
                        style={{
                            fontSize: 20,
                            fontWeight: 600,
                        }}
                    >
                        随机组卷
          </span>
                    <span>
                        {current === 0 ? BackButton : PrevButton}
                        {current === steps.length - 1 ? SubmitButton : NextButton}
                    </span>
                </div>
                <Card style={{ marginTop: 12, marginBottom: 200 }}>
                    <div style={{ display: "flex", justifyContent: "center" }}>
                        <Steps current={current} style={{ width: 780 }}>
                            {steps.map((item) => (
                                <Step key={item.title} title={item.title} />
                            ))}
                        </Steps>
                    </div>
                    <Divider></Divider>
                    <Spin spinning={this.state.loading}>
                        {steps.map((item, index) => {
                            return (
                                <div
                                    style={{ display: index === current ? "block" : "none" }}
                                    key={index}
                                >
                                    {item.content}
                                </div>
                            );
                        })}
                    </Spin>
                </Card>
            </div>
        );
    }
}

export default SnackbarHOC()(TPMIndexHOC(Form.create()(IntelligentPaper)));
