import React, { Component } from "react";
import TPMMDEditor from "../../../modules/tpm/challengesnew/TPMMDEditor";
import NullMDEditor from "../../courses/exercise/new/NullMDEditor";
import NullChildEditor from "../../courses/exercise/new/NullChildEditor";
import update from "immutability-helper";
import { validateLength } from "educoder";
import { Checkbox } from "antd";
//题库的试卷  填空题
class ComquestionEditor extends Component {
  constructor(props) {
    super(props);
    const { standard_answer } = this.props.item_banksedit;
    let _standard_answers = undefined;
    if (standard_answer) {
      _standard_answers = [];

      standard_answer.forEach((answers, index) => {
        _standard_answers.push([]);
        answers.answer_text.forEach((item, itemIndex) => {
          _standard_answers[index].push(item);
        });
      });
    }
    this.state = {
      question_title: this.props.item_banksedit.name || "",
      standard_answers: _standard_answers || [],
      question_analysis: this.props.item_banksedit.analysis || "",
      activeOptionErrorIndex: null,
      is_ordered: this.props.item_banksedit.is_ordered||false,
    };
  }

  componentDidMount() {
    if (this.props.getanswerMdRef) {
      this.props.getanswerMdRef(this);
    }
  }
  onContentChange = (label, value) => {
    this.setState({
      [label]: value,
    });
  };
  onSave = () => {
    let answerArray = [];
    let isEmpty = false;
    const { standard_answers } = this.state;
    standard_answers.forEach((answers, index) => {
      answerArray.push({
        position: index + 1,
        answer_text: [],
      });
      answers.forEach((item, itemIndex) => {
        answerArray[index].answer_text.push(item);
        if (!item || !validateLength(item, 10000)) {
          this.setState({
            activeOptionErrorIndex: `${index}-${itemIndex}`,
          });
          this.props.showNotification(
            !item ? `答案：不能为空` : "答案不能超过10000字符"
          );
          isEmpty = true;
        }
      });
    });
    return { ...this.state, isEmpty, answerArray };
  };

  onPlaceholderChange = (
    placeholderCountBefore,
    placeholderCountInRange,
    totalPlaceholderCount
  ) => {
    const { standard_answers } = this.state;
    const new_standard_answers = standard_answers.slice();
    if (placeholderCountInRange) {
      new_standard_answers.splice(
        placeholderCountBefore,
        placeholderCountInRange
      );
    }
    if (totalPlaceholderCount) {
      for (let i = 0; i < totalPlaceholderCount; i++) {
        new_standard_answers.splice(placeholderCountBefore + i, 0, [""]);
      }
    }
    this.setState({ standard_answers: new_standard_answers }, () => {
      if (this.mdReactObject) {
        this.mdReactObject.toShowMode();
      }
    });
  };
  onAnswerChange = (index, itemIndex, val) => {
    try {
      this.setState((prevState) => ({
        standard_answers: update(prevState.standard_answers, {
          [index]: { $splice: [[itemIndex, 1, val]] },
        }),
      }));
      if (this.state.activeOptionErrorIndex === `${index}-${itemIndex}`) {
        this.setState({ activeOptionErrorIndex: null });
      }
    } catch (error) {
      console.log(error, index, itemIndex, val);
    }
  };
  addChildAnswer = (index) => {
    this.setState((prevState) => ({
      standard_answers: update(prevState.standard_answers, {
        [index]: { $push: [""] },
      }),
    }));
  };
  deleteChildAnswer = (index, childIndex) => {
    if (!this.state.standard_answers[index][childIndex]) {
      this.setState((prevState) => ({
        standard_answers: update(prevState.standard_answers, {
          [index]: { $splice: [[childIndex, 1]] },
        }),
      }));
      return;
    }
    this.props.confirm({
      content: `确认要删除这个参考答案吗？`,
      onOk: () => {
        this.setState((prevState) => ({
          standard_answers: update(prevState.standard_answers, {
            [index]: { $splice: [[childIndex, 1]] },
          }),
        }));
      },
    });
  };
  deleteChildAnswermain = (index, childIndex) => {
    let newstandard_answers = this.state.standard_answers;

    this.props.confirm({
      content: `确认要删除这个参考答案吗？`,
      onOk: () => {
        newstandard_answers.splice(index, 1);
        this.setState({
          standard_answers: newstandard_answers,
        });
      },
    });
  };
  on_is_ordered_change = (e) => {
    this.setState({ is_ordered: e.target.checked });
  };
  render() {
    let { question_title, standard_answers, question_analysis } = this.state;
    return (
      <div className="padding20-30  signleEditor">
        <p className="mb10 clearfix">
          <span className="xingcolor font-16 fl mr4">*</span>
          <span className="xingtigan  fl">题干：</span>
        </p>
        <div>
          <NullMDEditor
            {...this.props}
            mdID={`completion-question-tittle`}
            placeholder="请您输入题目"
            height={155}
            initValue={question_title}
            onChange={(value) => this.onContentChange("question_title", value)}
            showNullButton={true}
            onPlaceholderChange={this.onPlaceholderChange}
          ></NullMDEditor>
        </div>
        <div className="clearfix mt20">
          {standard_answers.map((answers, index) => {
            return (
              <NullChildEditor
                key={index}
                ref={`nullChildEditor${index}`}
                {...this.props}
                answers={answers}
                index={index}
                is_md={true}
                activeOptionErrorIndex={this.state.activeOptionErrorIndex}
                onAnswerChange={this.onAnswerChange}
                addChildAnswer={this.addChildAnswer}
                deleteChildAnswer={this.deleteChildAnswer}
                deleteChildAnswermain={this.deleteChildAnswermain}
              ></NullChildEditor>
            );
          })}
        </div>
        <div className="clearfix mt20">
          {standard_answers.length > 1 ? (
            <span>
              <Checkbox
                checked={this.state.is_ordered}
                onChange={this.on_is_ordered_change}
                className="color-grey-3"
              >
                多个填空的答案有顺序要求
              </Checkbox>
              <span className="color-grey-9 font-12">
                （选中，每个填空的答案顺序必须与参考答案一致）
              </span>
            </span>
          ) : (
            ""
          )}
        </div>
        <div>
          <div className="mt20">
            <p className="mb10 clearfix">
              <span className="xingcolor font-16 fl mr4"></span>
              <span className="xingtigan  fl">题目解析：</span>
            </p>

            <TPMMDEditor
              initValue={question_analysis}
              height={166}
              mdID="subjective-question-analysis"
              onChange={(value) =>
                this.onContentChange("question_analysis", value)
              }
              placeholder="请您输入题目解析"
            />
          </div>
        </div>
      </div>
    );
  }
}
export default ComquestionEditor;
