import { useState, useCallback, useEffect, useRef, useMemo } from "react";

export function useToggle(init = false) {
  const [bool, setBool] = useState(init);
  const toggle = useCallback(() => {
    setBool((old) => !old);
  }, []);
  return [bool, toggle];
}

export function useForceUpdate() {
  const [_, setVer] = useState(0);
  return useCallback(() => {
    setVer((v) => v + 1);
  }, []);
}

export function useMap(canAdd, canRemove = () => true) {
  const mapRef = useRef(new Map());
  const forceUpdate = useForceUpdate();
  const add = useCallback((key, item) => {
    if (!canAdd(mapRef.current)) {
      return;
    }
    mapRef.current.set(key, item);
    forceUpdate();
  }, []);
  const remove = useCallback((key) => {
    mapRef.current.delete(key);
    forceUpdate();
  }, []);
  return { map: mapRef.current, add, remove };
}

export function useMap2(canAdd=()=>true,canRemove=()=>true){
  const forceUpdate = useForceUpdate();
  return useMemo(()=>{
    const map = new Map();
    map.set = function(k,v){
      if(canAdd(this)){
        Object.getPrototypeOf(this).set.call(this,k,v);
        forceUpdate();
      }
    }
    map.delete = function (k) {
      if(canRemove(this)){
        Object.getPrototypeOf(this).delete.call(this,k);
        forceUpdate();
      }
    }
    return map;
  },[]);
}

export function useLoaded(promiseFac, dependsLst) {
  const [isLoaded, setLoaded] = useState(false);
  const dataRef = useRef(null);
  useEffect(() => {
    let isUnmount = false;
    const f = async () => {
      dataRef.current = await promiseFac(...dependsLst);
      !isUnmount && setLoaded(true);
      dataRef.current = isUnmount?null:dataRef.current;
    };
    f();
    return () => {
      isUnmount = true;
      setLoaded(false);
    };
  }, dependsLst);
  return { isLoaded, data: dataRef.current };
}

export function useSet(canAdd = () => true) {
  const setRef = useRef(new Set());
  const forceUpdate = useForceUpdate();
  const add = useCallback((key) => {
    if(canAdd(setRef.current)){
      setRef.current.add(key);
      forceUpdate();
    }
  }, []);
  const remove = useCallback((key) => {
    setRef.current.delete(key);
    forceUpdate();
  }, []);
  return { set: setRef.current, add, remove };
}
